'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _Dom = require('../utils/Dom');

var _Dom2 = _interopRequireDefault(_Dom);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _SelectButton = require('./SelectButton');

var _SelectButton2 = _interopRequireDefault(_SelectButton);

var _IconButton = require('./IconButton');

var _IconButton2 = _interopRequireDefault(_IconButton);

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

var _styles = require('./styles');

var _ExpandMoreIcon = require('../icons/svg/ExpandMoreIcon');

var _ExpandMoreIcon2 = _interopRequireDefault(_ExpandMoreIcon);

var _uaParserJs = require('ua-parser-js');

var _uaParserJs2 = _interopRequireDefault(_uaParserJs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var uaParser = new _uaParserJs2.default();

/**
 * The right toolbar for an AppBar
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */

var AppBarRightToolbar = function (_Component) {
  _inherits(AppBarRightToolbar, _Component);

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */

  /**
   * Set accepted properties
   */
  function AppBarRightToolbar(props) {
    _classCallCheck(this, AppBarRightToolbar);

    // Variables used for callback refs
    var _this = _possibleConstructorReturn(this, (AppBarRightToolbar.__proto__ || Object.getPrototypeOf(AppBarRightToolbar)).call(this, props));
    // Call paprent constructor


    _this.shouldRightIconsMoveToSelectButton = function () {

      /*
       * If we have already evaluated that the right icons will be displayed in the select dropdown
       * Then, there is no need to re-evaluate
       */
      if (_this.state.useSelectButton) {
        return;
      }

      var domAppBarRight = _reactDom2.default.findDOMNode(_this.appBarRightContainer);
      var domAppBarParent = domAppBarRight && domAppBarRight.parentNode ? domAppBarRight.parentNode : null;

      if (domAppBarRight && domAppBarParent) {
        var offset = _Dom2.default.offset(domAppBarRight);
        var parentOffset = _Dom2.default.offset(domAppBarParent);

        /*
         * Check if appbarRight height is greater than the appbar client height
         * If the toolbar right icons is too many, the appBarRightContainer will overflow and its height will increase
         */
        if (offset.height > parentOffset.height) {
          // If so, then we need to set the state so it will use the SelectButton to display the icons
          _this.setState({ useSelectButton: true });
        }
      }
    };

    _this.appBarRightContainer = null;
    _this.appBarInnerContainer = null;

    _this.state = {
      useSelectButton: false
    };
    return _this;
  }

  /**
   * Set property defaults
   */


  _createClass(AppBarRightToolbar, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.shouldRightIconsMoveToSelectButton();
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      this.shouldRightIconsMoveToSelectButton();
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var classes = this.props.classes.innerRightContainer;
      if (this.props.className) {
        classes += ' ' + this.props.className;
      }

      var selectButtonIcons = [];
      var primaryIconButton = null;
      var minIconCountForSelectButton = 1;
      var iconButtons = [];
      var iconsForSelectButton = [];

      if (Array.isArray(this.props.children) == false) {
        // If there is only one icon then add it
        iconButtons.push(this.props.children);
      } else {
        // If we have more than one entry as children then we may need to fold them into a 'more' dropdown
        for (var idx in this.props.children) {
          var currentIcon = this.props.children[idx];

          // Let's verify if the currentIcon is a valid react element
          if (!currentIcon || !currentIcon.props) {
            continue;
          }

          // If we are dealing with primary icon and we dont have one, then we need to display it separately
          var isPrimaryIcon = currentIcon.props.isPrimary || false;

          if (isPrimaryIcon && !primaryIconButton) {
            minIconCountForSelectButton -= 1;
            primaryIconButton = currentIcon;
          } else if (currentIcon.type.name === 'AppBarSelectButton' || currentIcon.type.name === 'SelectButton') {
            // If we are dealing with dropdown icons, then we need to display it separately too
            minIconCountForSelectButton -= 1;
            selectButtonIcons.push(currentIcon);
          } else {
            iconButtons.push(currentIcon);

            var menuIcon = _react2.default.cloneElement(currentIcon, {
              key: 'menuIcon' + idx,
              primary: true
            });

            iconsForSelectButton.push(menuIcon);
          }
        }

        // We only need to use the select button if we are dealing with 2 or more icon buttons
        if (this.state.useSelectButton && iconButtons.length > minIconCountForSelectButton) {
          var menuItems = [];
          iconButtons = _react2.default.createElement(
            _SelectButton2.default,
            { menuItems: menuItems, icon: _react2.default.createElement(_ExpandMoreIcon2.default, null) },
            iconsForSelectButton
          );
        }
      }

      return _react2.default.createElement(
        'div',
        {
          className: classes,
          ref: function ref(appBarRightContainer) {
            _this2.appBarRightContainer = appBarRightContainer;
          }
        },
        primaryIconButton,
        iconButtons,
        selectButtonIcons
      );
    }

    /**
     * This will check if current toolbar right icons are too many to be displayed inline
     * If the right icons will overflow, we will set the state.useSelectButton to true
     * The right icons will be moved inside the select button dropdown
     */

  }]);

  return AppBarRightToolbar;
}(_react.Component);

// Wrap in JSS for styles


AppBarRightToolbar.propTypes = {
  /**
   * Optional class override
   */
  className: _propTypes2.default.string,

  /**
   * JSS classes for styling the component
   */
  classes: _propTypes2.default.object,

  /**
   * Child elements (text and icon)
   */
  children: _propTypes2.default.node
};
AppBarRightToolbar.defaultProps = {
  className: null
};
exports.default = (0, _injectStyles2.default)(_styles.styles, AppBarRightToolbar);
module.exports = exports['default'];