'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Avatar = function Avatar(props) {
  var children = null;
  if (props.src) {
    // Add the image to the avatar
    children = _react2.default.createElement('img', { alt: props.alt, src: props.src, className: props.classes.img });
  } else if (props.icon) {
    children = props.icon;
  } else {
    children = props.iconLetters;
  }

  var classes = props.classes.avatar;
  if (props.selected) {
    classes += ' ' + props.classes.selected;
  }

  return _react2.default.createElement(
    'div',
    { className: classes, style: props.style, onClick: props.onClick },
    children
  );
};

/**
 * Set property defaults
 */
Avatar.defaultProps = {
  onClick: null
};

Avatar.propTypes = {
  /**
   * JSS classes for styling the component
   */
  classes: _propTypes2.default.object,

  /**
   * Used if avatar is an image
   */
  src: _propTypes2.default.string,

  /**
   * Optional alt/title tag if using an image src
   */
  alt: _propTypes2.default.string,

  /**
   * An SvgIcon to be used instead of src
   */
  icon: _propTypes2.default.element,

  /**
   * Crate an avatar with letters like (FL) for Firstname Lastname
   */
  iconLetters: _propTypes2.default.string,

  /**
   * Optional style overrides
   */
  style: _propTypes2.default.object,

  /**
   * Indicate that the user has selected this avatar (change color)
   */
  selected: _propTypes2.default.bool,

  /**
   * Callback function that is called when the div was clicked
   */
  onClick: _propTypes2.default.func
};

exports.default = (0, _injectStyles2.default)(_styles.styles, Avatar);
module.exports = exports['default'];