'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _KeyCode = require('../utils/KeyCode');

var _KeyCode2 = _interopRequireDefault(_KeyCode);

var _FlatButton = require('../Button/FlatButton');

var _FlatButton2 = _interopRequireDefault(_FlatButton);

var _Overlay = require('../Overlay/Overlay');

var _Overlay2 = _interopRequireDefault(_Overlay);

var _Paper = require('../Paper/Paper');

var _Paper2 = _interopRequireDefault(_Paper);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Dialog window component
 */
var Dialog = function (_Component) {
  _inherits(Dialog, _Component);

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */
  function Dialog(props) {
    _classCallCheck(this, Dialog);

    // Create some references to dom elements for sizing
    var _this = _possibleConstructorReturn(this, (Dialog.__proto__ || Object.getPrototypeOf(Dialog)).call(this, props));
    // Call parent constructor


    _this.dismiss = function () {
      _this._onDismiss();
    };

    _this.show = function () {
      _this._focusOnAction();
      _this._onShow();
    };

    _this._handleOverlayTouchTap = function (e) {
      if (!_this.props.modal) {
        _this.dismiss();
        if (_this.props.onClickAway) _this.props.onClickAway();
      }
    };

    _this._handleWindowKeyUp = function (e) {
      if (!_this.props.modal && e.keyCode == _KeyCode2.default.ESC) {
        _this.dismiss();
      }
    };

    _this.refDialogWindow = _react2.default.createRef();
    _this.refDialogBody = _react2.default.createRef();
    _this.refDialogActions = _react2.default.createRef();

    _this.state = {
      // Used for dyanmic height (and scroll) of body for long content
      dialogBodyMaxHeight: null,
      // Used for auto positioning to the middle of the screen
      dialogWindowMarginTop: null
    };
    return _this;
  }

  _createClass(Dialog, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      // Variables used for callback refs
      this.dialogOverlay = null;
      this._positionDialog();

      // TODO
      // 'keyup': '_handleWindowKeyUp'

      if (this.props.showDialog && this.dialogOverlay) {
        this.dialogOverlay.preventScrolling();
        this._onShow();
        this._focusOnAction();
      }
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps, prevState) {
      // Ignore state change caused by _positionDialog() to avoid a continual loop
      if (this.state.dialogBodyMaxHeight == prevState.dialogBodyMaxHeight && this.state.dialogWindowMarginTop == prevState.dialogWindowMarginTop) {
        this._positionDialog();
        this._focusOnAction();
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var propsClasses = this.props.classes;

      // Set classes for window contents
      var classesWindow = propsClasses.dialogWindow;
      if (this.props.windowClassName) {
        classesWindow += ' ' + this.props.windowClassName;
      }

      // Set classes for dialog window
      var classesDialog = propsClasses.dialog;
      if (this.props.showDialog) {
        classesDialog += ' ' + propsClasses.dialogIsShown;

        if (this.props.fullPage) {
          classesWindow += ' ' + propsClasses.dialogWindowFullPage;
        } else {
          classesWindow += ' ' + propsClasses.dialogWindowInside;
        }
      }

      if (this.props.className) {
        classesDialog += ' ' + this.props.className;
      }

      // Set classes for window contents
      var classesWindowBody = propsClasses.dialogWindowBody;
      if (this.props.dialogWindowBodyClassName) {
        classesWindowBody += ' ' + this.props.dialogWindowBodyClassName;
      }

      // Add title
      var title = void 0;
      if (this.props.title) {
        // If the title is a string, wrap in an h3 tag.
        // If not, just use it as a node.
        title = Object.prototype.toString.call(this.props.title) === '[object String]' ? _react2.default.createElement(
          'h3',
          { className: propsClasses.dialogWindowTitle },
          this.props.title
        ) : this.props.title;
      }

      // Get actions to display at the bottom
      var actions = this._getActionsContainer(this.props.actions);

      return _react2.default.createElement(
        'div',
        { className: classesDialog },
        _react2.default.createElement(
          'div',
          {
            className: classesWindow,
            ref: this.refDialogWindow,
            style: this.state.dialogWindowMarginTop ? { marginTop: this.state.dialogWindowMarginTop } : {}
          },
          _react2.default.createElement(
            _Paper2.default,
            { zDepth: 4 },
            title,
            _react2.default.createElement(
              'div',
              {
                ref: this.refDialogBody,
                style: this.state.dialogBodyMaxHeight ? { maxHeight: this.state.dialogBodyMaxHeight } : {},
                className: classesWindowBody
              },
              this.props.children
            ),
            _react2.default.createElement(
              'div',
              { ref: this.refDialogActions },
              actions
            )
          )
        ),
        _react2.default.createElement(_Overlay2.default, {
          ref: function ref(dialogOverlay) {
            _this2.dialogOverlay = dialogOverlay;
          },
          show: this.props.showDialog,
          onClick: this._handleOverlayTouchTap
        })
      );
    }
  }, {
    key: 'isOpen',
    value: function isOpen() {
      return this.props.showDialog;
    }
  }, {
    key: 'reposition',


    /**
     * Reposition the dialog - usually means dynamic content changed
     */
    value: function reposition() {
      this._positionDialog();
    }
  }, {
    key: '_addClassName',
    value: function _addClassName(reactObject, className) {
      var originalClassName = reactObject.props.className;
      var newClassname = originalClassName ? originalClassName + ' ' + className : className;

      return _react2.default.cloneElement(reactObject, { className: newClassname });
    }
  }, {
    key: '_getAction',
    value: function _getAction(actionJSON, key) {
      var props = {
        key: key,
        secondary: true,
        onClick: actionJSON.onClick ? actionJSON.onClick : this.dismiss,
        label: actionJSON.text
      };
      if (actionJSON.ref) {
        props.ref = actionJSON.ref;
        props.keyboardFocused = actionJSON.ref === this.props.actionFocus;
      }

      return _react2.default.createElement(_FlatButton2.default, props);
    }
  }, {
    key: '_getActionsContainer',
    value: function _getActionsContainer(actions) {
      var actionContainer = void 0;
      var actionObjects = [];

      if (actions.length) {
        for (var i = 0; i < actions.length; i++) {
          var currentAction = actions[i];

          //if the current action isn't a react object, create one
          if (!_react2.default.isValidElement(currentAction)) {
            currentAction = this._getAction(currentAction, i);
          }

          currentAction = this._addClassName(currentAction, this.props.classes.dialogWindowAction);
          actionObjects.push(currentAction);
        }

        actionContainer = _react2.default.createElement(
          'div',
          { className: this.props.classes.dialogWindowActions },
          actionObjects
        );
      }

      return actionContainer;
    }

    /**
     * Make sure the dialog is correct positioned on the screen
     */

  }, {
    key: '_positionDialog',
    value: function _positionDialog() {
      if (this.props.showDialog && window) {
        var clientHeight = window.innerHeight;
        var dialogWindow = this.refDialogWindow.current;
        var dialogBody = this.refDialogBody.current;
        var minMarginTop = 0;

        // If we are running server-side or in automated tests element is not mounted
        if (!clientHeight || !dialogWindow || !dialogBody) {
          return;
        }

        // Props to set that will be used in this.setState at the end
        var dialogBodyMaxHeight = null;
        var dialogWindowMarginTop = null;

        var dialogWindowHeight = dialogWindow.offsetHeight;
        var windowTop = (clientHeight - dialogWindowHeight) / 2 - 2 * 64;

        // Set to full-height if we are in auto-detect
        if (this.props.autoDetectWindowHeight || this.props.autoScrollBodyContent) {
          windowTop = 0;
        } else if (windowTop < minMarginTop) {
          windowTop = minMarginTop;
        }

        //Vertically center the dialog window, but make sure it doesn't
        //transition to that position.
        if (this.props.repositionOnUpdate || !dialogWindow.style.marginTop) {
          dialogWindowMarginTop = windowTop + 'px';
        }

        // Force a height if the dialog is taller than clientHeight
        if (this.props.autoDetectWindowHeight || this.props.autoScrollBodyContent) {
          var maxDialogContentHeight = clientHeight - 2 * 64;

          if (this.props.title) {
            maxDialogContentHeight -= dialogBody.previousSibling.offsetHeight;
          }

          if (this.props.actions.length) {
            maxDialogContentHeight -= dialogBody.nextSibling.offsetHeight;
          }

          dialogBodyMaxHeight = maxDialogContentHeight + 'px';
        }

        // setState only if values changed (reduce re-rendering unnecessarily)
        if (this.state.dialogBodyMaxHeight != dialogBodyMaxHeight || this.state.dialogWindowMarginTop != dialogWindowMarginTop) {
          this.setState({
            dialogBodyMaxHeight: dialogBodyMaxHeight,
            dialogWindowMarginTop: dialogWindowMarginTop
          });
        }
      }
    }
  }, {
    key: '_focusOnAction',
    value: function _focusOnAction() {
      if (this.props.actionFocus) {
        console.error('We need to find a better way to do this');
        // if (ReactDOM.findDOMNode(this.refs[this.props.actionFocus])) {
        //   ReactDOM.findDOMNode(this.refs[this.props.actionFocus]).focus();
        // }
      }
    }
  }, {
    key: '_onShow',
    value: function _onShow() {
      if (this.props.onShow) this.props.onShow();
    }
  }, {
    key: '_onDismiss',
    value: function _onDismiss() {
      if (this.props.onDismiss) this.props.onDismiss();
    }
  }]);

  return Dialog;
}(_react.Component);

// Wrap in JSS for styles


Dialog.propTypes = {
  /**
   * Array of possible actions to create buttons for
   */
  actions: _propTypes2.default.array,

  /**
   * Which action should get focus when loaded
   */
  actionFocus: _propTypes2.default.string,

  /**
   * Automatically detect the ideal height of the window
   */
  autoDetectWindowHeight: _propTypes2.default.bool,

  /**
   * Automatically scroll the body of the window if larger than viewable area
   */
  autoScrollBodyContent: _propTypes2.default.bool,

  /**
   * Class to theme the content container
   */
  contentClassName: _propTypes2.default.string,

  /**
   * Depricated. Should be using showDialog.
   *
   * If true, open as soon as we mount into the dom.
   */
  openImmediately: _propTypes2.default.bool,

  /**
   * Action to perform when a user clicks away from the dialog
   */
  onClickAway: _propTypes2.default.func,

  /**
   * Callback to call when the dialog is dismissed
   */
  onDismiss: _propTypes2.default.func,

  /**
   * Callback to call when the dialog is shown
   */
  onShow: _propTypes2.default.func,

  /**
   * Automatically reposition the dialog if the contents change
   */
  repositionOnUpdate: _propTypes2.default.bool,

  /**
   * Do not allow the user to dismiss by clicking off the dialog
   */
  modal: _propTypes2.default.bool,

  /**
   * The title for the dialog window
   */
  title: _propTypes2.default.node,

  /**
   * Flag to set this dialog to take up 100% of the page
   */
  fullPage: _propTypes2.default.bool,

  /**
   * Flag that will determine if we are going to show the dialog or not
   */
  showDialog: _propTypes2.default.bool
};
Dialog.defaultProps = {
  autoDetectWindowHeight: false,
  autoScrollBodyContent: false,
  actions: [],
  repositionOnUpdate: true,
  modal: false,
  openImmediately: false
};
exports.default = (0, _injectStyles2.default)(_styles.styles, Dialog);
module.exports = exports['default'];