'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _Paper = require('../Paper/Paper');

var _Paper2 = _interopRequireDefault(_Paper);

var _Overlay = require('../Overlay/Overlay');

var _Overlay2 = _interopRequireDefault(_Overlay);

var _Dom = require('../utils/Dom');

var _Dom2 = _interopRequireDefault(_Dom);

var _KeyCode = require('../utils/KeyCode');

var _KeyCode2 = _interopRequireDefault(_KeyCode);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Navigation drawer component
 */
var Drawer = function (_Component) {
  _inherits(Drawer, _Component);

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */

  /**
   * Set accepted properties
   */
  function Drawer(props) {
    _classCallCheck(this, Drawer);

    var _this = _possibleConstructorReturn(this, (Drawer.__proto__ || Object.getPrototypeOf(Drawer)).call(this, props));
    // Call parent constructor


    _this._onOverlayTouchTap = function () {
      if (_this.props.onClose) _this.props.onClose();
    };

    _this._onWindowKeyUp = function (e) {
      if (e.keyCode == _KeyCode2.default.ESC && !_this.props.permanent && _this.state.open) {
        _this.close();
      }
    };

    _this.clickAwayableElement = _react2.default.createRef();
    _this.containerDomNode = _react2.default.createRef();

    _this.state = {
      open: _this.props.permanent,
      selected: '',
      curTopOffset: -1
    };
    return _this;
  }

  /**
   * Called once the drawer enters the DOM
   */


  /**
   * Set property defaults
   */


  _createClass(Drawer, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.updateOffsetFromTop();

      if (this.props.onDrawerIsRendered) {
        this.props.onDrawerIsRendered();
      }
    }

    /**
     * Handle changes needed before changes to props are applied
     *
     * @param {Object} nextProps
     */

  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      if (nextProps.open != this.props.open) {
        var isOpen = nextProps.open;
        // Ignore open if permanent is set
        if (nextProps.permanent) {
          isOpen = true;
        }

        this.setState({ open: isOpen });
      }
    }

    /**
     * Component props changed
     */

  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate() {
      if (this.state.curTopOffset === -1) {
        this.updateOffsetFromTop();
      }
    }

    /**
     * Render the component
     */

  }, {
    key: 'render',
    value: function render() {
      var _classnames;

      // Set the classes
      var classes = (0, _classnames3.default)(this.props.classes.drawer, (_classnames = {}, _defineProperty(_classnames, this.props.classes.drawerClosed, !this.props.open && !this.state.open), _defineProperty(_classnames, this.props.classes.drawerClipped, this.props.clipped), _defineProperty(_classnames, this.props.classes.drawerPermanent, this.props.permanent), _defineProperty(_classnames, this.props.classes.drawerFloating, !this.props.permanent), _defineProperty(_classnames, this.props.classes.drawerTransparent, this.props.zIndex == 0), _classnames), this.props.className);

      var overlay = void 0;

      if (!this.props.permanent) overlay = _react2.default.createElement(_Overlay2.default, { show: this.props.open || this.state.open, onClick: this._onOverlayTouchTap });

      // Determine the depth of the background
      var zDept = this.props.permanent ? 0 : 1;

      // Handle offset when the document scrolls and the menu is not already at the top
      var topStyle = {};

      // Manually set the height
      var heightToUse = this.getHeight();
      if (heightToUse > 0) {
        topStyle.height = heightToUse + 'px';
      }

      return _react2.default.createElement(
        'div',
        { ref: this.containerDomNode },
        overlay,
        _react2.default.createElement(
          _Paper2.default,
          {
            style: topStyle,
            ref: this.clickAwayableElement,
            className: classes,
            zDepth: zDept,
            rounded: false
          },
          this.props.children
        )
      );
    }
  }, {
    key: 'getHeight',


    /**
     * Determine the height needed based on props
     */
    value: function getHeight() {
      // Only adjust if mounted AND open
      if (typeof window != 'undefined' || !this.state.open) {
        return 0;
      }

      var height = window.innerHeight;

      // Get the offset if the drawer is clipped
      if (this.props.clipped && this.state.curTopOffset) {
        height -= this.state.curTopOffset;
      }

      return height;
    }

    /**
     * Any time the offset of the drawer from the top of the page changed we should update it
     */

  }, {
    key: 'updateOffsetFromTop',
    value: function updateOffsetFromTop() {
      // Only adjust if mounted, open, and clipped
      if (!window || !this.state.open || !this.props.clipped) {
        return;
      }

      var drawerOffset = _Dom2.default.offset(this.containerDomNode.current);
      if (drawerOffset.top > 0) {
        this.setState({
          curTopOffset: drawerOffset.top
        });
      }
    }

    /**
     * Toggle this opened and closed
     */

  }, {
    key: 'toggle',
    value: function toggle() {
      this.setState({ open: !this.state.open });
    }
  }]);

  return Drawer;
}(_react.Component);

// Wrap in JSS for styles


Drawer.propTypes = {
  /**
   * Flag to indicate if the drawer is open
   */
  open: _propTypes2.default.bool,

  /**
   * If permanent we cannot close the drawer
   */
  permanent: _propTypes2.default.bool,

  /**
   * If permanent and clipped then the drawer will show up under the appBar
   */
  clipped: _propTypes2.default.bool,

  /**
   * Optional element to anchor the meny to
   */
  anchorEl: _propTypes2.default.object,

  /**
   * Callback any time the menu should close
   */
  onClose: _propTypes2.default.func,

  /**
   * Which side to display the drawer on
   *
   * Options
   * left: primary and default navigation
   * right: secondary right side navigation
   */
  side: _propTypes2.default.oneOf(['left', 'right']),

  /**
   * Optioanl class name override
   */
  className: _propTypes2.default.string,

  /**
   * Optioanl zIndex to load for the drawer - defautls to 200 in CSS
   */
  zIndex: _propTypes2.default.number,

  /**
   * Child elements to be rendered into the Drawer
   */
  children: _propTypes2.default.node,

  /**
   * Callback function that is called whtn the drawer is finished loading
   */
  onDrawerIsRendered: _propTypes2.default.func
};
Drawer.defaultProps = {
  open: false,
  permanent: false,
  clipped: false,
  anchorEl: null,
  side: 'left'
};
exports.default = (0, _injectStyles2.default)(_styles.styles, Drawer);
module.exports = exports['default'];