'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _RichText = require('../Input/RichText');

var _RichText2 = _interopRequireDefault(_RichText);

var _RichTextIframe = require('../Input/RichTextIframe');

var _RichTextIframe2 = _interopRequireDefault(_RichTextIframe);

var _EditorToolbar = require('./EditorToolbar');

var _EditorToolbar2 = _interopRequireDefault(_EditorToolbar);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

var _uaParserJs = require('ua-parser-js');

var _uaParserJs2 = _interopRequireDefault(_uaParserJs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Contains both the toolbar and an instance of RichText component
 */
var ContentHtml = function (_Component) {
  _inherits(ContentHtml, _Component);

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */
  function ContentHtml(props) {
    _classCallCheck(this, ContentHtml);

    var _this = _possibleConstructorReturn(this, (ContentHtml.__proto__ || Object.getPrototypeOf(ContentHtml)).call(this, props));
    // Call parent constructor


    _this._onChange = function (value) {
      if (_this.props.onChange) {
        _this.props.onChange(value);
      }

      _this.setState({ value: value });
    };

    _this._onToggle = function (value) {
      if (_this.props.onChange) {
        _this.props.onChange(value);
      }

      _this.setState({
        value: value,
        toggleStyle: null,
        toggleType: null
      });
    };

    _this._onBlur = function (value) {
      if (_this.props.onBlur) {
        _this.props.onBlur(value);
      } else {
        //this.setState({value});
      }
    };

    _this._onFocus = function (value) {
      if (_this.props.onFocus) {
        _this.props.onFocus(value);
      } else {
        //this.setState({value});
      }
    };

    _this._handleStyleToggle = function (style, type) {
      _this.setState({
        toggleStyle: style,
        toggleType: type
      });
    };

    _this._handleContentViewToggle = function (contentView) {
      if (_this.props.onContentViewToggle) {
        _this.props.onContentViewToggle(contentView, _this.state.value);
      }
    };

    _this.state = {
      value: _this.props.value,
      toggleStyle: null,
      toggleType: null,
      // Used to change behavior based on problems with android
      deviceOsName: null,
      deviceBrowserName: null
    };
    return _this;
  }

  /**
   * Handle when the editor has changed
   *
   * @param {string} value The value of the editor
   * @private
   */


  /**
   * Handle when the editor looses the focus
   *
   * @param {string} value The value of the editor
   * @private
   */


  /**
   * Handles when the user set the focus in the editor
   *
   * @param {string} value The value of the editor
   * @private
   */


  /**
   * Handles the toggling of styles in the toolbar icons
   *
   * @param {string} style The style that was clicked. It is either block style or inline style
   * @param {string} type The style type that was toggled. (e.g. bold, italic, underline, h1, h2, h3, ul, ol)
   * @private
   */


  /**
   * Handles the toggling of content view
   *
   * @param {int} contentView The content view we are switching to
   * @private
   */


  _createClass(ContentHtml, [{
    key: 'componentDidMount',


    /**
     * Component mounted into the DOM tree
     */
    value: function componentDidMount() {
      var uaParser = new _uaParserJs2.default();
      if (uaParser.getOS().name && uaParser.getBrowser().name) {
        this.setState({
          deviceOsName: uaParser.getOS().name.toLowerCase(),
          deviceBrowserName: uaParser.getBrowser().name.toLowerCase()
        });
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var RichTextComponent = _RichText2.default;

      if (this.state.deviceOsName) {
        // Check if the user is using android. If so, then let's use RichTextIframe for now
        if (this.state.deviceOsName === 'android' || this.state.deviceBrowserName === 'android browser') {
          RichTextComponent = _RichTextIframe2.default;
        }
      }

      return _react2.default.createElement(
        'div',
        { className: this.props.classes.richTextContainer },
        _react2.default.createElement(_EditorToolbar2.default, {
          contentViewType: this.props.contentViewType,
          onStyleToggle: this._handleStyleToggle,
          onContentViewToggle: this._handleContentViewToggle
        }),
        _react2.default.createElement(RichTextComponent, {
          commandToggleType: this.state.toggleType,
          commandToggleStyle: this.state.toggleStyle,
          onToggle: this._onToggle,
          onChange: this._onChange,
          onBlur: this._onBlur,
          onFocus: this._onFocus,
          value: this.state.value
        })
      );
    }
  }]);

  return ContentHtml;
}(_react.Component);

/**
 * Set accepted properties
 */


ContentHtml.propTypes = {
  /**
   * The callback function used when user changes the content of the editor
   *
   * @type {function}
   */
  onChange: _propTypes2.default.func,

  /**
   * The callback function used when user looses the focus of the editor
   *
   * @type {function}
   */
  onBlur: _propTypes2.default.func,

  /**
   * The initial value of the content editor
   *
   * @type {string}
   */
  value: _propTypes2.default.string,

  /**
   * Handles the toggling of content view
   *
   * @type {function}
   */
  onContentViewToggle: _propTypes2.default.func
};

// Wrap in JSS for styles
exports.default = (0, _injectStyles2.default)(_styles.styles, ContentHtml);
module.exports = exports['default'];