'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Create styles for each column class
 *
 * @param {int} cols
 * @param {int} outOfTotalCols
 */
var createColStyles = function createColStyles(cols) {
  var outOfTotalCols = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 12;

  return {
    flex: '0 0 ' + cols / outOfTotalCols * 100 + '%',
    maxWidth: cols / outOfTotalCols * 100 + '%'
  };
};

var styles = exports.styles = function styles(theme) {
  var _containerCentered;

  var mediaMedium = '@media (min-width: ' + theme.breakpoints.medium + 'px)';
  var mediaLarge = '@media (min-width: ' + theme.breakpoints.large + 'px)';
  var mediaxLarge = '@media (min-width: ' + theme.breakpoints.xLarge + 'px)';

  var classes = {
    container: {
      marginLeft: theme.gutters.small + 'px',
      marginRight: theme.gutters.small + 'px',
      boxSizing: 'border-box'
    },

    containerCentered: (_containerCentered = {}, _defineProperty(_containerCentered, mediaMedium, { width: '750px', marginLeft: 'auto', marginRight: 'auto' }), _defineProperty(_containerCentered, mediaLarge, { width: '970px', marginLeft: 'auto', marginRight: 'auto' }), _defineProperty(_containerCentered, mediaxLarge, { width: '1170px', marginLeft: 'auto', marginRight: 'auto' }), _containerCentered),

    /**
     * Used to remove gutters from the container for nested grids
     */
    containerNoGutter: {
      marginRight: 0,
      marginLeft: 0
    },

    row: {
      marginLeft: theme.gutters.small / -2 + 'px',
      marginRight: theme.gutters.small / -2 + 'px',
      boxSizing: 'border-box',
      display: 'flex',
      flexWrap: 'wrap'
    },

    column: {
      paddingLeft: theme.gutters.small / 2 + 'px',
      paddingRight: theme.gutters.small / 2 + 'px',
      minHeight: '1px',
      boxSizing: 'border-box',
      flex: 1
    },

    /**
     * Horizontal gutter spacer to add spacing between row elements
     */
    gutterHoriz: {
      height: theme.gutters.small + 'px'
    },

    /**
     * Horizontal divider used to provide spacing between rows
     */
    dividerHoriz: {
      height: '1px',
      backgroundColor: theme.borderColor
    }
  };

  // Small columns need to be printed first so they can be over-ridden below
  for (var cols = 1; cols <= 12; cols++) {
    classes['colSmall' + cols] = createColStyles(cols);
  }

  // Add medium columns
  for (var _cols = 1; _cols <= 12; _cols++) {
    classes['colMedium' + _cols] = _defineProperty({}, mediaMedium, createColStyles(_cols));
  }

  // Add large columns
  for (var _cols2 = 1; _cols2 <= 12; _cols2++) {
    classes['colLarge' + _cols2] = _defineProperty({}, mediaLarge, createColStyles(_cols2));
  }

  // Add xlarge columns
  for (var _cols3 = 1; _cols3 <= 12; _cols3++) {
    classes['colXLarge' + _cols3] = _defineProperty({}, mediaxLarge, createColStyles(_cols3));
  }

  return classes;
};