'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Chip = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _CloseIcon = require('../icons/svg/CloseIcon');

var _CloseIcon2 = _interopRequireDefault(_CloseIcon);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Grouping Chip
 *
 * @param {Object} props
 * @returns {ReactDOM}
 * @constructor
 */
var Chip = exports.Chip = function Chip(props) {
  var children = props.children,
      deletable = props.deletable;


  var classes = props.classes.chip || '';
  if (props.className) {
    classes += ' ' + props.className;
  }

  var displayDeleteButton = null;
  if (deletable) {
    displayDeleteButton = _react2.default.createElement(
      'span',
      { className: props.classes.deletable, onClick: props.onDeleteClick },
      _react2.default.createElement(_CloseIcon2.default, { size: 18 })
    );
  }

  var displayChildren = children;
  if (typeof displayChildren === 'string') {
    displayChildren = _react2.default.createElement(
      'span',
      null,
      children
    );
  }

  return _react2.default.createElement(
    'div',
    { className: classes },
    _react2.default.createElement(
      'div',
      { className: props.classes.chipChildren },
      displayChildren
    ),
    displayDeleteButton
  );
};

/**
 * Set accepted properties
 */
Chip.propTypes = {
  /**
   * Optional class override
   */
  className: _propTypes2.default.string,

  /**
   * JSS classes for styling the component
   */
  classes: _propTypes2.default.object,

  /**
   * Child elements (text and icon)
   */
  children: _propTypes2.default.node,

  /**
   * Flag that will determine if the grouping chip will be displaying the delete icon
   */
  deletable: _propTypes2.default.bool,

  /**
   * Callback function that is called when clicking the delete icon
   */
  onDeleteClick: _propTypes2.default.func
};

// Wrap in JSS for styles
exports.default = (0, _injectStyles2.default)(_styles.styles, Chip);