'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Functional component for any button
 *
 * @param props
 * @returns {ReactDOM}
 * @constructor
 */
var List = function List(props) {
  var currentIndex = 0;
  var childElements = _react.Children.map(props.children, function (child) {
    var retChild = child;
    if (_react2.default.isValidElement(child) && props.selectable) {
      retChild = _react2.default.cloneElement(child, {
        selected: props.selectedIndex === currentIndex
      });
    }

    // Increment index to keep track of selected
    currentIndex++;

    return retChild;
  });

  return _react2.default.createElement(
    'div',
    null,
    childElements
  );
};

/**
 * Set accepted properties
 */
List.propTypes = {
  /**
   * Child nodes
   */
  children: _propTypes2.default.node,

  /**
   * Can the user select an item from the list
   */
  selectable: _propTypes2.default.bool,

  /**
   * Optional currently selected index if selectable
   */
  selectedIndex: _propTypes2.default.number
};

/**
 * Set property defaults
 */
List.defaultProps = {
  selectable: false,
  selectedIndex: null
};

exports.default = List;
module.exports = exports['default'];