'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _TouchRipple = require('../ripples/TouchRipple');

var _TouchRipple2 = _interopRequireDefault(_TouchRipple);

var _classnames3 = require('classnames');

var _classnames4 = _interopRequireDefault(_classnames3);

var _Checkbox = require('../Toggle/Checkbox');

var _Checkbox2 = _interopRequireDefault(_Checkbox);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

var _BodyLeadText = require('../Text/BodyLeadText');

var _BodyLeadText2 = _interopRequireDefault(_BodyLeadText);

var _BodyText = require('../Text/BodyText');

var _BodyText2 = _interopRequireDefault(_BodyText);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Functional component for any button
 *
 * @param props
 * @returns {ReactDOM}
 * @constructor
 */
var ListItem = function ListItem(props) {
  var _classnames;

  var classes = (0, _classnames4.default)(props.classes.listItem, (_classnames = {}, _defineProperty(_classnames, props.classes.listItemSelected, props.selected), _defineProperty(_classnames, props.classes.listItemEmphasized, props.emphasized), _defineProperty(_classnames, props.classes.listItemTappable, props.onTap || props.onClick), _classnames));

  var contentClasses = (0, _classnames4.default)(props.classes.listItemContent, _defineProperty({}, props.classes.listItemContentAlignTop, props.children && !props.primaryText));

  // Set ontap functions
  var actionCallback = props.onTap || props.onClick;
  var onTap = actionCallback ? actionCallback : function () {};
  var onLeftElementTap = null;

  if (props.onLeftElementTap) {
    onLeftElementTap = function onLeftElementTap(e) {
      e.stopPropagation();
      props.onLeftElementTap(e);
    };
  }

  // If we have a left element add it
  var leftElement = null;
  if (props.leftElement) {
    var leftIcon = props.selected && props.selectedShowCheckbox ? _react2.default.createElement(_Checkbox2.default, { checked: true }) : props.leftElement;

    leftElement = _react2.default.createElement(
      'div',
      { onClick: onLeftElementTap, className: props.classes.listItemLeft },
      leftIcon
    );
  }

  // If we have a right element add it
  var rightElement = props.rightElement ? _react2.default.createElement(
    'div',
    { className: props.classes.listItemRight },
    props.rightElement
  ) : null;

  var bodyStyle = {
    margin: 0,
    overflow: 'hidden',
    textOverflow: 'ellipsis'
  };

  return _react2.default.createElement(
    'div',
    { className: classes, onClick: onTap },
    _react2.default.createElement(
      _TouchRipple2.default,
      { disabled: props.onTap === null },
      _react2.default.createElement(
        'div',
        { className: contentClasses },
        leftElement,
        _react2.default.createElement(
          'div',
          { className: props.classes.listItemData },
          _react2.default.createElement(
            'div',
            null,
            _react2.default.createElement(
              _BodyLeadText2.default,
              { style: bodyStyle },
              props.primaryText
            ),
            _react2.default.createElement(
              _BodyText2.default,
              { style: bodyStyle },
              props.secondaryText
            )
          ),
          props.children
        ),
        rightElement
      )
    )
  );
};

/**
 * Set accepted properties
 */
ListItem.propTypes = {
  /**
   * Primary text/title of the item
   */
  primaryText: _propTypes2.default.string,

  /**
   * Secondary text for the item - often a snippet of the body
   */
  secondaryText: _propTypes2.default.string,

  /**
   * Optional children to render into the item
   */
  children: _propTypes2.default.node,

  /**
   * Optional flag that can be set to indicate this item is selected
   */
  selected: _propTypes2.default.bool,

  /**
   * Show a checkbox if this item is slected (or on mouse hover to indicate it can be)
   */
  selectedShowCheckbox: _propTypes2.default.bool,

  /**
   * Used to highlight an entry - often used to mark a new entry
   */
  emphasized: _propTypes2.default.bool,

  /**
   * Node element to render on the left side
   */
  leftElement: _propTypes2.default.node,

  /**
   * Node element to render on the right side
   */
  rightElement: _propTypes2.default.node,

  /**
   * Legacy event called when the primary action is tapped or Clicked
   */
  onTap: _propTypes2.default.func,

  /**
   * Event called when the primary action is tapped or Clicked
   */
  onClick: _propTypes2.default.func,

  /**
   * Event called when the left element is tapped or Clicked
   */
  onLeftElementTap: _propTypes2.default.func,

  /**
   * JSS classes for styling the component
   */
  classes: _propTypes2.default.object
};

/**
 * Set property defaults
 */
ListItem.defaultProps = {
  primaryText: null,
  secondaryText: null,
  leftElement: null,
  rightElement: null,
  selected: false,
  emphasized: false,
  onTap: null
};

exports.default = (0, _injectStyles2.default)(_styles.styles, ListItem);
module.exports = exports['default'];