'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

var _Checkbox = require('../Toggle/Checkbox');

var _Checkbox2 = _interopRequireDefault(_Checkbox);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Functional component for any button
 *
 * @param props
 * @returns {ReactDOM}
 * @constructor
 */
var ListItemCheckbox = function ListItemCheckbox(props) {
  var classes = (0, _classnames3.default)(props.classes.listItem, _defineProperty({}, props.classes.listItemSelected, props.checked));

  // Create a change function to call in case the user did not pass one
  var onChange = function onChange(e, checked) {
    if (props.onChange) {
      props.onChange(e, checked);
    }
  };

  // If we have a right element add it
  var rightElement = props.rightElement ? _react2.default.createElement(
    'div',
    { className: props.classes.listItemRight },
    props.rightElement
  ) : null;

  return _react2.default.createElement(
    'div',
    { className: classes },
    _react2.default.createElement(
      'div',
      { className: props.classes.listItemContent },
      _react2.default.createElement(
        'div',
        { className: props.classes.listItemLeft },
        _react2.default.createElement(_Checkbox2.default, { onChange: onChange, checked: props.checked })
      ),
      _react2.default.createElement(
        'div',
        {
          className: props.classes.listItemData,
          onClick: function onClick(e) {
            onChange(e, !props.checked);
          }
        },
        _react2.default.createElement(
          'div',
          { className: props.classes.listItemPrimary },
          props.primaryText
        ),
        _react2.default.createElement(
          'div',
          { className: props.classes.listItemSecondary },
          props.secondaryText
        )
      ),
      rightElement
    )
  );
};

/**
 * Set accepted properties
 */
ListItemCheckbox.propTypes = {
  /**
   * Primary text/title of the item
   */
  primaryText: _propTypes2.default.string,

  /**
   * Secondary text for the item - often a snippet of the body
   */
  secondaryText: _propTypes2.default.string,

  /**
   * Node element to render on the right side
   */
  rightElement: _propTypes2.default.node,

  /**
   * Event called when we select the control
   */
  onChange: _propTypes2.default.func,

  /**
   * Bool to set whether or not this element is checked
   */
  checked: _propTypes2.default.bool,

  /**
   * JSS classes for styling the component
   */
  classes: _propTypes2.default.object
};

/**
 * Set property defaults
 */
ListItemCheckbox.defaultProps = {
  primaryText: null,
  secondaryText: null,
  leftElement: null,
  rightElement: null,
  checked: false
};

exports.default = (0, _injectStyles2.default)(_styles.styles, ListItemCheckbox);
module.exports = exports['default'];