'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Outer container for tabs
 */
var Tabs = function (_Component) {
  _inherits(Tabs, _Component);

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */
  function Tabs(props) {
    _classCallCheck(this, Tabs);

    var _this2 = _possibleConstructorReturn(this, (Tabs.__proto__ || Object.getPrototypeOf(Tabs)).call(this, props));
    // Call parent constructor


    _this2.handleTouchTap = function (tabIndex, tab) {
      if (_this2.props.onChange && _this2.state.selectedIndex !== tabIndex) {
        _this2.props.onChange(tabIndex, tab);
      }

      _this2.setState({ selectedIndex: tabIndex });
      //default CB is _onActive. Can be updated in tab
      if (tab.props.onActive) tab.props.onActive(tab);
    };

    var selectedIndex = 0;
    if (_this2.props.initialSelectedIndex && _this2.props.initialSelectedIndex < _this2.props.children.length) {
      selectedIndex = _this2.props.initialSelectedIndex;
    }

    _this2.state = {
      selectedIndex: selectedIndex
    };
    return _this2;
  }

  _createClass(Tabs, [{
    key: 'getEvenWidth',
    value: function getEvenWidth() {
      try {
        var computedStyle = window.getComputedStyle(_reactDom2.default.findDOMNode(this));
        return parseInt(computedStyle.getPropertyValue('width'), 10);
      } catch (e) {
        return 0;
      }

      return 0;
    }
  }, {
    key: 'getTabCount',
    value: function getTabCount() {
      return _react2.default.Children.count(this.props.children);
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      if (this.props.tabWidth) {
        if (!(this.props.children.length * this.props.tabWidth > this.getEvenWidth())) {
          this.setState({
            width: this.props.tabWidth,
            fixed: false
          });
          return;
        }
      }

      this.setState({
        width: this.getEvenWidth(),
        fixed: true
      });
    }

    /**
     * Handle touch or click
     *
     * @param tabIndex
     * @param tab
     */

  }, {
    key: 'render',
    value: function render() {
      var _this = this;
      var propsClasses = this.props.classes;
      var width = 100 / this.getTabCount() + '%';

      // Get classes for the tab item container
      var tabItemContainerClasses = this.props.secondary ? propsClasses.tabItemContainerSecondary : propsClasses.tabItemContainer;
      var tabUnderlineBar = this.props.secondary ? propsClasses.tabInkBarSecondary : propsClasses.tabInkBar;

      /*
       var width = this.state.fixed ?
       this.state.width/this.props.children.length :
       this.props.tabWidth;*/
      var left = 'calc(' + width + '*' + this.state.selectedIndex + ')';
      //var left = width * this.state.selectedIndex || 0;
      var currentTemplate = null;
      var tabs = _react2.default.Children.map(this.props.children, function (tab, index) {
        // Generic UI implementation
        if (_this.state.selectedIndex === index) currentTemplate = tab.props.children;
        return _react2.default.cloneElement(tab, {
          key: index,
          selected: _this.state.selectedIndex === index,
          tabIndex: index,
          width: width,
          secondary: _this.props.secondary,
          handleTouchTap: _this.handleTouchTap
        });
      });

      return _react2.default.createElement(
        'div',
        { className: propsClasses.tabsContainer },
        _react2.default.createElement(
          'div',
          { className: tabItemContainerClasses },
          tabs
        ),
        _react2.default.createElement('div', { className: tabUnderlineBar, style: { left: left, width: width } }),
        _react2.default.createElement(
          'div',
          { className: propsClasses.tabTemplate },
          currentTemplate
        )
      );
    }
  }]);

  return Tabs;
}(_react.Component);

// Wrap in JSS for styles


Tabs.propTypes = {
  /**
   * Which index to select first after render is done
   *
   * Defaults to 0. This is good for thins like saving the
   * state of the UI re-opening a page back to the selected tab
   */
  initialSelectedIndex: _propTypes2.default.number,

  /**
   * Callback to notify listener when the selected index changes
   */
  onChange: _propTypes2.default.func,

  /**
   * Set a static tab width.
   *
   * If not set all tabs will be automatically computed to evenly fill
   * 100% of the container width
   */
  tabWidth: _propTypes2.default.number,

  /**
   * Used for inline body tabs rather than at the top of the page
   */
  secondary: _propTypes2.default.bool
};
exports.default = (0, _injectStyles2.default)(_styles.styles, Tabs);
module.exports = exports['default'];