'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _htmlReactParser = require('html-react-parser');

var _htmlReactParser2 = _interopRequireDefault(_htmlReactParser);

var _domToReact = require('html-react-parser/lib/dom-to-react');

var _domToReact2 = _interopRequireDefault(_domToReact);

var _HeadingText = require('./HeadingText');

var _HeadingText2 = _interopRequireDefault(_HeadingText);

var _BodyText = require('./BodyText');

var _BodyText2 = _interopRequireDefault(_BodyText);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Local transform to convert html elements to chamel elements
 *
 * @param {Object} domNode Node we are transforming
 * @param {Object} parserOptions Passed from parent for recurrsive processing
 */
var transformHtmlToChamel = function transformHtmlToChamel(domNode, parserOptions) {
  if (domNode.type === 'tag') {
    switch (domNode.name) {
      case 'h1':
        {
          return _react2.default.createElement(
            _HeadingText2.default,
            { level: 1 },
            (0, _domToReact2.default)(domNode.children, parserOptions)
          );
        }
      case 'h2':
        {
          return _react2.default.createElement(
            _HeadingText2.default,
            { level: 2 },
            (0, _domToReact2.default)(domNode.children, parserOptions)
          );
        }
      case 'h3':
        {
          return _react2.default.createElement(
            _HeadingText2.default,
            { level: 3 },
            (0, _domToReact2.default)(domNode.children, parserOptions)
          );
        }
      case 'h4':
        {
          return _react2.default.createElement(
            _HeadingText2.default,
            { level: 4 },
            (0, _domToReact2.default)(domNode.children, parserOptions)
          );
        }
      case 'p':
        {
          return _react2.default.createElement(
            _BodyText2.default,
            null,
            (0, _domToReact2.default)(domNode.children, parserOptions)
          );
        }
    }
  }
};

/**
 * Render an HTML string
 *
 * @param {Object} props
 * @returns {Object}
 */
var HtmlText = function HtmlText(props) {
  var parserOptions = {
    replace: function replace(domNode) {
      // First check for custom transform
      if (props.transform) {
        var transformedComponent = props.transform(domNode);
        if (transformedComponent) {
          return transformedComponent;
        }
      }

      // Use standard transforms
      return transformHtmlToChamel(domNode, parserOptions);
    }
  };

  var sanitizedHtml = props.html.replace('<html>', '<div>').replace('</html>', '</div>');
  return _react2.default.createElement(
    'div',
    null,
    (0, _htmlReactParser2.default)(sanitizedHtml, parserOptions)
  );
};

/**
 * Accepted PropTypes
 */
HtmlText.propTypes = {
  /**
   * JSS styles
   */
  classes: _propTypes2.default.object,

  /**
   * Raw HTML string to render
   */
  html: _propTypes2.default.string
};

// Wrap in JSS for styles
exports.default = HtmlText;
module.exports = exports['default'];