'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _TouchRipple = require('../ripples/TouchRipple');

var _TouchRipple2 = _interopRequireDefault(_TouchRipple);

var _FocusRipple = require('../ripples/FocusRipple');

var _FocusRipple2 = _interopRequireDefault(_FocusRipple);

var _toggleCheckBoxOutlineBlank = require('../svg-icons/toggle-check-box-outline-blank');

var _toggleCheckBoxOutlineBlank2 = _interopRequireDefault(_toggleCheckBoxOutlineBlank);

var _toggleCheckBoxChecked = require('../svg-icons/toggle-check-box-checked');

var _toggleCheckBoxChecked2 = _interopRequireDefault(_toggleCheckBoxChecked);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Functional component for any button
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
var Checkbox = function Checkbox(props, context) {
  var propsClasses = props.classes;
  var onTap = props.onChange && !props.disabled ? function (evt) {
    if (props.onChange) {
      props.onChange(evt, !props.checked);
    } else if (props.onCheck) {
      props.onCheck(evt, !props.checked);
    }
  } : null;

  var labelElement = null;
  if (props.label) {
    labelElement = _react2.default.createElement(
      'div',
      { className: propsClasses.checkboxText },
      props.label
    );
  }

  var outlineClasses = propsClasses.checkboxIconBox;
  if (props.checked) {
    outlineClasses += ' ' + propsClasses.checkboxIconBoxOn;
  }

  var checkClasses = propsClasses.checkboxIconCheck;
  if (props.checked) {
    checkClasses += ' ' + propsClasses.checkboxIconCheckOn;
  }

  return _react2.default.createElement(
    'div',
    { onClick: onTap, className: propsClasses.checkbox },
    _react2.default.createElement(
      'div',
      { className: propsClasses.checkboxIcon },
      _react2.default.createElement(_toggleCheckBoxOutlineBlank2.default, { className: outlineClasses }),
      _react2.default.createElement(_toggleCheckBoxChecked2.default, { className: checkClasses })
    ),
    labelElement
  );
};

/**
 * Set accepted properties
 */
Checkbox.propTypes = {
  children: _propTypes2.default.node,
  className: _propTypes2.default.string,
  disabled: _propTypes2.default.bool,
  label: _propTypes2.default.string,

  /**
   * This is the function calling components should use to check status
   */
  onChange: _propTypes2.default.func,

  /**
   * Legacy callback
   */
  onCheck: _propTypes2.default.func,

  /**
   * Flag indicates whether or not the input box is checked
   */
  checked: _propTypes2.default.bool
};

/**
 * Set property defaults
 */
Checkbox.defaultProps = {
  className: '',
  checked: false
};

// Wrap in JSS for styles
exports.default = (0, _injectStyles2.default)(_styles.styles, Checkbox);
module.exports = exports['default'];