'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _IconButton = require('../Button/IconButton');

var _IconButton2 = _interopRequireDefault(_IconButton);

var _ChevronLeftIcon = require('../icons/svg/ChevronLeftIcon');

var _ChevronLeftIcon2 = _interopRequireDefault(_ChevronLeftIcon);

var _ChevronRightIcon = require('../icons/svg/ChevronRightIcon');

var _ChevronRightIcon2 = _interopRequireDefault(_ChevronRightIcon);

var _Dom = require('../utils/Dom');

var _Dom2 = _interopRequireDefault(_Dom);

var _Events = require('../utils/Events');

var _Events2 = _interopRequireDefault(_Events);

var _styles = require('./styles');

var _injectStyles = require('../styles/injectStyles');

var _injectStyles2 = _interopRequireDefault(_injectStyles);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * This variable will hold all the icons to be displayed in the toolbar
 *
 * If we are in mobile mode display, then we will evaluate the icon's width
 *  to determine how many icons will fit in the current toolbar.
 * Arrow navigation icons will be displayed if we have more icons to display
 *
 * @type {Array}
 */
var toolbarIcons = [];

/**
 * Main popover class handles absolute positioning paper relative to an element
 */

var Toolbar = function (_Component) {
  _inherits(Toolbar, _Component);

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */
  function Toolbar(props) {
    _classCallCheck(this, Toolbar);

    // Variables used for callback refs
    var _this = _possibleConstructorReturn(this, (Toolbar.__proto__ || Object.getPrototypeOf(Toolbar)).call(this, props));
    // Call paprent constructor


    _this._onWindowScroll = function () {
      // If the starting state was 0 then do nothing
      if (!_this.props.alwaysVisible) {
        return;
      }

      // Get the scroll offset of the window
      var windowOffset = _Dom2.default.scrollOffset();

      /*
       * If we have scrolled, then follow the scroll.
       * Because the left nav div is position:fixed, then we
       * can move all the way to 0 to be at the top no matter how
       * far down the page they scroll
       */
      var newTop = _this.state.startTopOffset - windowOffset.top;
      if (newTop < 0) {
        newTop = 0;
      }

      // Restore the original state if we are back in the viewport.
      if (windowOffset.top <= _this.state.startTopOffset) {
        newTop = -1; // Reset
      }

      // Set state
      _this.setState({ curTopOffset: newTop });
    };

    _this.outerCon = null;
    _this.toolbarDiv = null;

    _this.state = {
      /**
       * The width of the toolbar icons container
       *
       * This will determine if the icons to be displayed will fit in the toolbar
       */
      chamelToolbarWidth: 0,

      /**
       * The starting index of the icon that we are going to display
       *
       * This will be used if we are displaying the arrow navigation keys in the toolbar
       */
      startIconIndex: 0,

      /**
       * For alwaysVisible toolbars, we need to keep track of where
       * we started on the page so we can float when scrolling
       */
      curTopOffset: -1
    };
    return _this;
  }

  /**
   * Set accepted properties
   */


  _createClass(Toolbar, [{
    key: 'componentDidMount',


    /**
     * Called when component enters the DOM
     */
    value: function componentDidMount() {
      // Get the offsetWidth of the main container for the toolbar icons
      if (this.outerCon) {
        var offset = _Dom2.default.offset(this.outerCon);

        this.setState({
          chamelToolbarWidth: offset.width,
          startTopOffset: offset.top
        });
      }

      _Events2.default.on(window, 'scroll', this._onWindowScroll);
    }

    /**
     * Called just before component leaves the DOM
     */

  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      _Events2.default.off(window, 'scroll', this._onWindowScroll);
    }

    /**
     * Catch updates before they are applied
     */

  }, {
    key: 'componentWillUpdate',
    value: function componentWillUpdate() {
      /*
       * If the toolbarIcons length is 0, then we will get the toolbar icons from _getToolbarIcons()
       *
       * We need to get the icons here (componentWillUpdate)
       *  because the icons should be rendered first before we can get the icons (html nodes)
       */
      if (toolbarIcons.length == 0) {
        var level = 0;

        // Get the toolbar icons
        if (this.props.children && this.toolbarDiv) {
          this._getToolbarIcons(this.props.children, this.toolbarDiv, level);
        }
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      var propsClasses = this.props.classes;

      /*
       * This will contain the total icons width to be displayed in the toolbar
       * And will be evaluated later to determine if we will display the arrow navigation keys
       */
      var totalIconsWidth = 0;

      // Let's calculate the total toolbar icons width, so we can evaluate if we need to display the arrow buttons
      toolbarIcons.map(function (icon) {
        totalIconsWidth += icon.width;
      });

      var classes = propsClasses.toolbar;
      if (this.props.secondary) {
        classes += ' ' + propsClasses.toolbarSecondary;
      }

      // Handle floating the toolbar if we have scrolled and want it alwaysVisible
      var innerConStyle = null;
      if (this.props.alwaysVisible && this.state.curTopOffset !== -1) {
        innerConStyle = {
          top: this.state.curTopOffset + 'px',
          width: this.state.chamelToolbarWidth + 'px'
        };

        classes += ' ' + propsClasses.fixedBelowAppbar;
      }

      /*
       * Check if we should try to dynamically resize the toolbar
       */
      if (toolbarIcons.length != 0 && totalIconsWidth > this.state.chamelToolbarWidth) {
        /*
         * If the width of the totalIcons is greater than our toolbarWidth
         * then we need to evaluate how many icons should be displayed
         *
         * We will also display here the arrow navigation keys to browse the toolbars that are not displayed
         */
        var displayArrowLeft = null,
            displayArrowRight = null,
            totalDisplayIconWidth = 0,
            displayIcons = [],
            idx = this.state.startIconIndex;

        // Loop thru the toolbarIcons and evaluate how many icons will fit in the current toolbar's width
        for (var i = 1; i <= toolbarIcons.length; i++, idx++) {
          // Make sure that we will only evaluate if we have a toolbar icon
          if (toolbarIcons[idx]) {
            // Calculate the width of the total icons displayed
            totalDisplayIconWidth += toolbarIcons[idx].width;

            /*
             * If the width of the total icons displayed reaches the limit (chamelToolbarWidth)
             * Then we will break this for loop and will not add more toolbar icons to displayIcons
             *
             * We need to minus the toolbarWidth with 96 to accommodate the arrow navigation buttons
             */
            if (totalDisplayIconWidth > this.state.chamelToolbarWidth - 144) {
              break;
            }

            /*
             * The number of icons to be displayed are limited because we need to make sure that
             *  they will fit in the toolbar main container's width
             */
            displayIcons.push(toolbarIcons[idx].icon);
          }
        }

        // This will determine if we need to display the left arrow icon
        if (this.state.startIconIndex > 0) {
          displayArrowLeft = _react2.default.createElement(
            'div',
            { className: propsClasses.chamelToolbarLeftArrow },
            _react2.default.createElement(
              _IconButton2.default,
              {
                onTap: function onTap(e) {
                  _this2._handleArrowClick(-1);
                }
              },
              _react2.default.createElement(_ChevronLeftIcon2.default, null)
            )
          );
        } else {
          displayArrowLeft = null;
        }

        // This will determine if we need to display the right arrow icon
        if (this.state.startIconIndex + displayIcons.length < toolbarIcons.length) {
          displayArrowRight = _react2.default.createElement(
            'div',
            { className: propsClasses.chamelToolbarRightArrow },
            _react2.default.createElement(
              _IconButton2.default,
              {
                onTap: function onTap(e) {
                  _this2._handleArrowClick(1);
                }
              },
              _react2.default.createElement(_ChevronRightIcon2.default, null)
            )
          );
        }

        // Modify the toolbar main container's style so we can properly display the toolbar icons
        var iconContainerStyle = {
          textAlign: 'left',
          display: 'inline-block'
        };

        return _react2.default.createElement(
          'div',
          {
            ref: function ref(outerCon) {
              _this2.outerCon = outerCon;
            }
          },
          _react2.default.createElement(
            'div',
            {
              ref: function ref(toolbarCon) {
                _this2.toolbarDiv = toolbarCon;
              },
              style: innerConStyle,
              className: classes
            },
            displayArrowLeft,
            _react2.default.createElement(
              'div',
              { className: this.toolbarGroup, style: iconContainerStyle },
              displayIcons
            ),
            displayArrowRight
          )
        );
      } else {
        // If the toolbar main container is wide enough to display all the icons, then just display the props.children
        return _react2.default.createElement(
          'div',
          {
            ref: function ref(outerCon) {
              _this2.outerCon = outerCon;
            }
          },
          _react2.default.createElement(
            'div',
            {
              ref: function ref(outerCon) {
                _this2.toolbarDiv = outerCon;
              },
              style: innerConStyle,
              className: classes
            },
            this.props.children
          )
        );
      }
    }

    /**
     * Callback used to handle the clicking of the navigation arrow icons
     *
     * @param {int} value The number that will be used to modify the div's left value (negative value = left key; positive value = right key)
     * @private
     */

  }, {
    key: '_handleArrowClick',
    value: function _handleArrowClick(value) {
      // Update the startIconIndex
      var startIconIndex = this.state.startIconIndex + value;
      this.setState({ startIconIndex: startIconIndex });
    }

    /**
     * Function that will get the icon's width
     *
     * @param {DOMNode} element The icon element that we want to get the width
     * @returns {int} The icon's width
     * @private
     */

  }, {
    key: '_getIconWidth',
    value: function _getIconWidth(element) {
      var style = element.currentStyle || window.getComputedStyle(element);

      var width = parseInt(style.width, 10) + parseInt(style.marginLeft, 10) + parseInt(style.marginRight, 10) + parseInt(style.paddingLeft, 10) + parseInt(style.paddingRight, 10);

      if (width == 0 || isNaN(width)) {
        width = element.offsetWidth;
      }

      return width;
    }

    /**
     * Function that will get all the toolbar icons
     *
     * @param {React.Children} children The children of the react component that contains the possible toolbar icons
     * @param {DOMNode} elementContainer The parent node of the elemeent
     * @param {int} level Determine how deep we have checked to look for toolbar icons
     * @private
     */

  }, {
    key: '_getToolbarIcons',
    value: function _getToolbarIcons(children, elementContainer, level) {
      // Limitation: Currently, we can handle 1 level deep (which is the <ToolbarGroup> as the element container)
      if (level > 1) {
        // TODO: If level 2 or more, then we need to be able to check if the child element is an icon or not
        return;
      }

      for (var idx in children) {
        var child = children[idx];
        var element = elementContainer.childNodes[idx];

        // If we do not have an element, then we do not need to continue
        if (!element) {
          continue;
        }

        // If the current element is a div and has child nodes, then we will assume that it contains toolbar icons
        if (element.nodeType && element.tagName.toLowerCase() === 'div' && child.props.children) {
          this._getToolbarIcons(child.props.children, element, level + 1);
        } else if (element.nodeType) {
          toolbarIcons.push({
            icon: child,
            width: this._getIconWidth(element)
          });
        }
      }
    }

    /**
     * If the toolbar is supposed to be alwaysVisible, make sure
     * it does not scroll off the page
     */

  }]);

  return Toolbar;
}(_react.Component);

// Wrap in JSS for styles


Toolbar.propTypes = {
  /**
   * If this is a secondary menu then it might be used inline in the document
   */
  secondary: _propTypes2.default.bool,

  /**
   * AppBaR will always remain at the top of the page on scroll
   *
   * Fixed will override this option if both are true
   */
  alwaysVisible: _propTypes2.default.bool
};
exports.default = (0, _injectStyles2.default)(_styles.styles, Toolbar);
module.exports = exports['default'];