'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactJss = require('react-jss');

var _jss = require('jss');

var _jss2 = _interopRequireDefault(_jss);

var _jssPresetDefault = require('jss-preset-default');

var _jssPresetDefault2 = _interopRequireDefault(_jssPresetDefault);

var _reboot = require('./reboot');

var _reboot2 = _interopRequireDefault(_reboot);

var _themeAutoSelector = require('./themeAutoSelector');

var _globalStyles = require('./globalStyles');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

// Use default plugins - https://github.com/cssinjs/jss-preset-default
_jss2.default.setup((0, _jssPresetDefault2.default)());

/* 
 * Add reboot.css. Set render index to -100002 because react-jss starts
 * injecting at -100000 in order to make sure components are rendered
 * in the correct order right before the theme global styles @ -1000001
 * See https://github.com/cssinjs/react-jss/blob/master/src/injectSheet.js
 */
_jss2.default.createStyleSheet(_reboot2.default, { index: -100002, meta: 'reboot' }).attach();

/**
 * Theme provider to provide chameleon styles to all children
 */

var ChamelThemeProvider = function (_Component) {
  _inherits(ChamelThemeProvider, _Component);

  _createClass(ChamelThemeProvider, [{
    key: 'getChildContext',


    /**
     * Pass theme down for any child components to access directly
     */
    value: function getChildContext() {
      return {
        chamelTheme: this.state.selectedTheme
      };
    }

    /**
     * Class constructor takes properties and passes them to the parent/super
     *
     * @param {Object} props React props
     */


    /**
     * We provide the selected theme for any child components to access directly
     */

  }]);

  function ChamelThemeProvider(props) {
    _classCallCheck(this, ChamelThemeProvider);

    // Reference to the global style sheet if set
    var _this = _possibleConstructorReturn(this, (ChamelThemeProvider.__proto__ || Object.getPrototypeOf(ChamelThemeProvider)).call(this, props));

    _this.globalStyleSheet = null;

    _this.state = {
      selectedTheme: props.theme || (0, _themeAutoSelector.getTheme)()
    };
    return _this;
  }

  /**
   * Set global settings on mount
   */


  _createClass(ChamelThemeProvider, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      if (this.state.selectedTheme && this.props.setGlobalStyles) {
        this.setGlobalStyles();
      }
    }

    /**
     * If no theme was provided on mount, then retrieve from user agent
     */

  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      if (this.props.theme != prevProps.theme && this.props.theme != this.state.selectedTheme) {
        this.setState({
          selectedTheme: this.props.theme || (0, _themeAutoSelector.getTheme)()
        });
        this.setGlobalStyles();
      }
    }

    /* 
     * Add global styles from the theme settings.
     * injecting at -1000002 in order to make sure components are rendered
     * in the correct order right after reboot @ -1000001
     * See https://github.com/cssinjs/react-jss/blob/master/src/injectSheet.js
     */

  }, {
    key: 'setGlobalStyles',
    value: function setGlobalStyles() {
      if (this.globalStyleSheet) {
        _jss2.default.removeStyleSheet(this.globalStyleSheet);
      }

      // Create the style sheet
      this.globalStyleSheet = _jss2.default.createStyleSheet((0, _globalStyles.styles)(this.state.selectedTheme), {
        index: -100002,
        meta: 'themeglobal'
      });

      this.globalStyleSheet.attach();
    }

    /**
     * Render into the DOM
     */

  }, {
    key: 'render',
    value: function render() {
      var theme = this.state.selectedTheme ? this.state.selectedTheme : {};
      return _react2.default.createElement(
        _reactJss.ThemeProvider,
        { theme: theme },
        this.props.children
      );
    }
  }]);

  return ChamelThemeProvider;
}(_react.Component);

ChamelThemeProvider.propTypes = {
  /**
   * All the descendent children of this provider
   */
  children: _propTypes2.default.element,

  /**
   * Theme properties object
   */
  theme: _propTypes2.default.object,

  /**
   * If true the theme will set global document styles
   */
  setGlobalStyles: _propTypes2.default.bool
};
ChamelThemeProvider.childContextTypes = {
  chamelTheme: _propTypes2.default.object
};
exports.default = ChamelThemeProvider;
module.exports = exports['default'];