'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _colors = require('./colors');

var _colors2 = _interopRequireDefault(_colors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// The the primary and acceent colors for this theme
var primaryColor1 = _colors2.default.lightBlue500;
var primaryColor2 = _colors2.default.lightBlue700;
var primaryColor3 = _colors2.default.lightBlue100;
var accentColor1 = _colors2.default.pinkA200;
var accentColor2 = _colors2.default.pinkA400;
var accentColor3 = _colors2.default.pinkA100;

var iconSize = 24;
var desktopKeylineUncrement = 64;
var desktopSubheaderHeight = 48;

// Transitions
var easeOutFunction = 'cubic-bezier(0.23, 1, 0.32, 1)';
var easeOutDefault = 'all 450ms ' + easeOutFunction + ' 0ms';

/**
 * Gutters for spacing
 */
var gutters = {
  large: 32,
  medium: 24,
  small: 16
};

// Export them base theme which should be pretty simple
var base = {
  themeName: 'base',

  primaryColor1: primaryColor1,
  primaryColor2: primaryColor2,
  primaryColor3: primaryColor3,
  accentColor1: accentColor1,
  accentColor2: accentColor2,
  accentColor3: accentColor3,

  defaultIconSize: iconSize,

  thumbnailSize: 150,

  /**
   * Default border color used for most borders
   */
  borderColor: _colors2.default.grey300,

  /**
   * Device size breakpoints in pixels
   */
  breakpoints: {
    small: 375,
    medium: 768,
    large: 992,
    xLarge: 1200
  },

  gutters: gutters,

  body: {
    backgroundColor: '#ffffff'
  },

  /**
   * Chip variables
   */
  chip: {
    backgroundColor: primaryColor1,
    textColor: _colors2.default.white,
    fontSize: '16px'
  },

  /**
   * AppBar variables
   */
  appBar: {
    heightSmall: '48px',
    heightMedium: '56px',
    heightLarge: '64px',
    centerConPadding: '0 0 0 ' + gutters.small + 'px',
    title: {
      fontSize: '20px',
      fontWeight: 'bold',
      textAlign: 'left'
    },
    backgroundColor: primaryColor1,
    textColor: _colors2.default.darkWhite
  },

  /**
   * Toolbar variables
   */
  toolbar: {
    backgroundColor: _colors2.default.grey300
  },

  /**
   * Button variables
   */
  button: {
    buttonHeight: '36px',
    buttonMinWidth: '88px',
    buttonBorderRadius: '2px',
    boxShadow: '0 1px 4px ' + _colors2.default.minBlack,
    buttonSizeNormal: 56,
    buttonSizeSmall: 40,
    buttonSizeIcon: iconSize * 2,
    textTransform: 'uppercase',

    // Raied button
    raisedPrimaryHover: primaryColor3,
    raisedPrimaryBackgroundColor: primaryColor1,
    raisedPrimaryTextColor: _colors2.default.white,
    raisedAccentHover: accentColor3,
    raisedAccentBackgroundColor: accentColor1,
    raisedAccentTextColor: _colors2.default.white,

    // Flat Button
    flatBackgroundColor: 'transparent',
    flatTextColor: _colors2.default.darkBlack,
    flatPrimaryHover: _colors2.default.grey300,
    flatPrimaryBackgroundColor: _colors2.default.white,
    flatPrimaryTextColor: primaryColor1,
    flatAccentHover: _colors2.default.grey300,
    flatAccentBackgroundColor: _colors2.default.white,
    flatAccentTextColor: accentColor1,

    // Icon Button
    iconPrimaryTextColor: primaryColor1,
    iconAccenttextColor: accentColor1,

    // Dark Button
    darkHover: _colors2.default.grey50,
    darkBackgroundColor: _colors2.default.darkBlack,
    darktextColor: _colors2.default.white,

    // Light Button
    lightHover: _colors2.default.grey300,
    lightBackgroundColor: _colors2.default.white,
    lightTextColor: _colors2.default.darkBlack,

    // Disabled
    disabledTextColor: _colors2.default.grey400
  },

  /**
   * Dialog variables
   */
  dialog: {
    maxWidth: desktopKeylineUncrement * 12 + 'px',
    canvasColor: _colors2.default.white,
    transition: 'top 0ms ' + easeOutFunction + ' 450ms',
    windowTransform: 'translate3d(0, ' + desktopKeylineUncrement + 'px, 0)',
    windowTransformEaseOut: easeOutDefault
  },

  /**
   * Drawer variables
   */
  drawer: {
    leftNavWidth: desktopKeylineUncrement * 4 + 'px',
    transform: 'translate3d(' + (-1 * (desktopKeylineUncrement * 4) - 10) + 'px, 0, 0 )',
    easeOutDefault: easeOutDefault
  },

  /**
   * Font variables
   */
  font: {
    family: '"Roboto", "Helvetica", "Arial", sans-serif',
    colorScheme: {
      dark: 'rgba(0, 0, 0, 0.54)',
      darkInactive: 'rgba(0, 0, 0, 0.26)',
      light: 'rgba(255, 255, 255, 1)',
      lightInactive: 'rgba(255, 255, 255, 0.3)'
    },
    display1: {
      size: '112px',
      weight: 200,
      color: 'rgba(0, 0, 0, 0.54)'
    },
    display2: {
      size: '56px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.54)'
    },
    display3: {
      size: '45px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.54)'
    },
    display4: {
      size: '34px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.54)'
    },
    heading1: {
      size: '28px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.87)'
    },
    heading2: {
      size: '24px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.87)'
    },
    heading3: {
      size: '20px',
      weight: 500,
      color: 'rgba(0, 0, 0, 0.87)'
    },
    heading4: {
      size: '16px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.87)'
    },
    body: {
      size: '14px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.87)'
    },
    lead: {
      size: '14px',
      weight: 500,
      color: 'rgba(0, 0, 0, 0.87)'
    },
    caption: {
      size: '16px',
      weight: 400,
      color: 'rgba(0, 0, 0, 0.54)'
    }
  },

  /**
   * Input variables
   */
  input: {
    transition: 'height 200ms ' + easeOutFunction + ' 0ms',
    easeOutDefault: easeOutDefault,
    blockQuoteTextColor: _colors2.default.grey50,
    scale: {
      zero: 'scaleX(0)',
      one: 'scaleX(1)',
      default: 'scale(1) translate3d(0, 0, 0)',
      float: 'scale(0.75) translate3d(0, -26px, 0)'
    },
    colorScheme: {
      bodyTextColor: _colors2.default.darkBlack,
      disabledTextColor: _colors2.default.grey400,
      errorTextColor: _colors2.default.red500,
      primaryColor: primaryColor1
    }
  },

  /**
   * List
   */
  list: {
    itemHoverColor: 'rgba(0, 0, 0, .035)',
    itemPadding: gutters.small + 'px',
    itemSelectedTextColor: primaryColor1,
    itemSelectedBackgroundColor: 'transparent',
    subHeaderPadding: gutters.more
  },

  table: {
    cellPadding: gutters.small + 'px'
  },

  menu: {
    backgroundColor: _colors2.default.white,
    iconColor: _colors2.default.faintBlack,
    selectedTextColor: accentColor1,
    hoverColor: 'rgba(0, 0, 0, .035)',
    disabledTextColor: _colors2.default.grey400,
    itemHeight: '48px',
    itemDataHeight: '32px',
    easeOutDefault: easeOutDefault
  },

  overlay: {
    backgroundColor: _colors2.default.lightBlack,
    transition: 'left 0ms ' + easeOutFunction + ' 0ms, background-color 400ms ' + easeOutFunction + ' 0ms',
    windowTransform: 'translate3d(0, 0, 0)'
  },

  picker: {
    iconSize: iconSize,
    iconColor: _colors2.default.faintBlack,
    borderColor: _colors2.default.grey300,
    menuBackgroundColor: _colors2.default.white,
    selectFieldHeight: iconSize * 2,
    selectFieldIconTop: iconSize / 4,
    colorSchemes: {
      primary: {
        backgroundColor: _colors2.default.white,
        textColor: primaryColor1
      },
      dark: {
        backgroundColor: _colors2.default.darkBlack,
        textColor: _colors2.default.white
      },
      light: {
        backgroundColor: _colors2.default.white,
        textColor: _colors2.default.lightBlack
      }
    }
  },

  progress: {
    backgroundImage: 'linear-gradient(to right, rgba(255, 64, 129, 0.7), rgba(255, 64, 129, 0.7)), linear-gradient(to right, ' + primaryColor1 + ', ' + primaryColor1 + ')',
    disabledBackgroundImage: 'linear-gradient(to right, rgba(255, 64, 129, 0.7), rgba(255, 64, 129, 0.7)), linear-gradient(to right, ' + _colors2.default.grey400 + ', ' + _colors2.default.grey400 + ')',
    backgroundColor: _colors2.default.grey200,
    mainColor: primaryColor1,
    curveDefault: 'cubic-bezier(0.4, 0, 0.2, 1)',
    animationDuration: '.35',
    scaleRatio: '1.25'
  },

  ripples: {
    circleInnerBackgroundColor: _colors2.default.grey400,
    easeOutDefault: easeOutDefault,
    easeOutRippleCirle: 'opacity 2s ' + easeOutFunction + ' 0ms',
    easeOutRippleCirleInner: 'transform 1s ' + easeOutFunction + ' 0ms'
  },

  snackbar: {
    textColor: _colors2.default.white,
    backgroundColor: _colors2.default.nightBlack,
    actionColor: accentColor1,
    height: desktopSubheaderHeight + 'px',
    easeOutDefault: easeOutDefault
  },

  tabs: {
    height: '48px',
    fontSize: '14sp',
    textColor: _colors2.default.white,
    activeTextColor: _colors2.default.white,
    backgroundColor: primaryColor1,
    activeBackgroundColor: 'transparent',
    secondaryTextColor: _colors2.default.black,
    secondaryActiveTextColor: _colors2.default.black,
    easeOutInkBar: 'left 1s ' + easeOutFunction + ' 0ms',
    tabsContainerBorder: '0',
    tabsContainerBorderRadius: '0',
    inkBarBackgroundColor: 'yellow'
  },

  toggle: {
    toggleSize: '20px',
    checkboxSize: iconSize + 'px',
    checkedColor: primaryColor1,
    uncheckedColor: _colors2.default.black,
    thumbColorOff: _colors2.default.grey50,
    thumbColorOn: primaryColor1,
    trackColorOff: _colors2.default.minBlack,
    trackColorOn: 'fade-out(' + primaryColor1 + ', 0.5)',
    transition: 'opacity 450ms ' + easeOutFunction + ' 0ms, transform 0ms ' + easeOutFunction + ' 450ms',
    transitionCheckOn: 'opacity 0ms ' + easeOutFunction + ' 0ms, transform 800ms ' + easeOutFunction + ' 0ms',
    easeOutBoxOn: 'all 100s ' + easeOutFunction + ' 0ms',
    easeOutIconBox: 'all 2s ' + easeOutFunction + ' 200ms',
    easeOutDefault: easeOutDefault
  },

  avatar: {
    backgroundColor: _colors2.default.grey400,
    color: _colors2.default.white,
    selectedColor: primaryColor1,
    selectedBackgroundColor: primaryColor3
  },

  paper: {
    roundedBorderRadius: '3px',
    backgroundColorDepth1: 'transparent',
    boxShadowDepth1: '0 1px 4px rgba(0, 0, 0, 0.24)',
    boxShadowDepth1Bottom: '0 1px 6px rgba(0, 0, 0, 0.12)',
    borderDepth1: '0',
    backgroundColorDepth2: 'transparent',
    boxShadowDepth2: '0 3px 10px rgba(0, 0, 0, 0.23)',
    boxShadowDepth2Bottom: '0 3px 10px rgba(0, 0, 0, 0.16)',
    borderDepth2: '0',
    backgroundColorDepth3: 'transparent',
    boxShadowDepth3: '0 6px 10px rgba(0, 0, 0, 0.23)',
    boxShadowDepth3Bottom: '0 10px 30px rgba(0, 0, 0, 0.19)',
    borderDepth3: '0',
    backgroundColorDepth4: 'transparent',
    boxShadowDepth4: '0 10px 18px rgba(0, 0, 0, 0.22)',
    boxShadowDepth4Bottom: '0 14px 45px rgba(0, 0, 0, 0.25)',
    borderDepth4: '0',
    backgroundColorDepth5: 'transparent',
    boxShadowDepth5: '0 15px 20px rgba(0, 0, 0, 0.22)',
    boxShadowDepth5Bottom: '0 19px 60px rgba(0, 0, 0, 0.30)',
    borderDepth5: '0'
  }
};

exports.default = base;
module.exports = exports['default'];