'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _colors = require('./colors');

var _colors2 = _interopRequireDefault(_colors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// The the primary and acceent colors for this theme
var primaryColor1 = '#007acc';
var primaryColor2 = '#005a97';
var primaryColor3 = '#9cdcfe';
var accentColor1 = _colors2.default.pinkA200;
var accentColor2 = _colors2.default.pinkA400;
var accentColor3 = _colors2.default.pinkA100;

var iconSize = 24;

// Transitions
var easeOutFunction = 'cubic-bezier(0.23, 1, 0.32, 1)';
var easeOutDefault = 'all 450ms ' + easeOutFunction + ' 0ms';

/**
 * Gutters for spacing
 */
var gutters = {
  large: 32,
  medium: 24,
  small: 16
};

/**
 * Theme matching windows modern design
 *
 * These variables will override the theme variables found in base
 * so it is only necessary to set properties that need to be different
 * than the base theme.
 */
var modern = {
  themeName: 'modern',
  primaryColor1: primaryColor1,
  primaryColor2: primaryColor2,
  primaryColor3: primaryColor3,
  accentColor1: accentColor1,
  accentColor2: accentColor2,
  accentColor3: accentColor3,

  /**
   * Borders like hr and separators in lists and table
   */
  borderColor: '#393939',

  font: {
    family: '"Segoe UI", Arial, Verdana, Helvetica, sans-serif',
    colorScheme: {
      dark: 'rgba(255, 255, 255, 0.54)',
      darkInactive: 'rgba(255, 255, 255, 0.26)',
      light: 'rgba(255, 255, 255, 1)',
      lightInactive: 'rgba(255, 255, 255, 0.3)'
    },
    display1: {
      size: '112px',
      weight: 200,
      color: 'rgba(255, 255, 255, 0.54)'
    },
    display2: {
      size: '56px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)'
    },
    display3: {
      size: '45px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)'
    },
    display4: {
      size: '34px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)'
    },
    heading1: {
      size: '28px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)'
    },
    heading2: {
      size: '24px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)'
    },
    heading3: {
      size: '20px',
      weight: 500,
      color: 'rgba(255, 255, 255, 0.87)'
    },
    heading4: {
      size: '16px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)'
    },
    body: {
      size: '14px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)'
    },
    lead: {
      size: '14px',
      weight: 500,
      color: 'rgba(255, 255, 255, 0.87)'
    },
    caption: {
      size: '16px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)'
    }
  },

  /**
   * Input variables
   */
  input: {
    transition: 'height 200ms ' + easeOutFunction + ' 0ms',
    easeOutDefault: easeOutDefault,
    blockQuoteTextColor: _colors2.default.darkWhite,
    scale: {
      zero: 'scaleX(0)',
      one: 'scaleX(1)',
      default: 'scale(1) translate3d(0, 0, 0)',
      float: 'scale(0.75) translate3d(0, -26px, 0)'
    },
    colorScheme: {
      bodyTextColor: _colors2.default.white,
      disabledTextColor: _colors2.default.darkWhite,
      errorTextColor: _colors2.default.red500,
      primaryColor: primaryColor3
    }
  },

  body: {
    //backgroundColor: '#252526',
    backgroundColor: '#333333'
  },

  /**
   * AppBar variables
   */
  appBar: {
    heightSmall: '48px',
    heightMedium: '56px',
    heightLarge: '64px',
    centerConPadding: '0 0 0 ' + gutters.small + 'px',
    title: {
      fontSize: '20px',
      fontWeight: 500,
      textAlign: 'left'
    },
    backgroundColor: primaryColor1,
    textColor: _colors2.default.darkWhite
  },

  /**
   * List
   */
  list: {
    itemHoverColor: 'rgba(255, 255, 255, .040)',
    itemPadding: gutters.small + 'px',
    itemSelectedTextColor: 'inherit',
    itemSelectedBackgroundColor: '#3f3f46',
    // itemPrimaryColor: colors.grey50,
    // itemSecondaryColor: colors.amber200,
    subHeaderPadding: gutters.more
  },

  table: {
    cellPadding: gutters.small + 'px'
  },

  menu: {
    backgroundColor: _colors2.default.darkBlack,
    iconColor: _colors2.default.white,
    selectedTextColor: accentColor1,
    hoverColor: 'rgba(255, 255, 255, .035)',
    disabledTextColor: _colors2.default.grey400,
    itemHeight: '48px',
    itemDataHeight: '32px',
    easeOutDefault: easeOutDefault
  },

  /**
   * Chip variables
   */
  chip: {
    backgroundColor: primaryColor1,
    textColor: _colors2.default.white,
    fontSize: '16px'
  },

  /**
   * Toolbar variables
   */
  toolbar: {
    backgroundColor: _colors2.default.darkBlack
  },

  /**
   * Button variables
   */
  button: {
    buttonHeight: '36px',
    buttonMinWidth: '88px',
    buttonBorderRadius: '2px',
    boxShadow: '0 1px 4px ' + _colors2.default.minBlack,
    buttonSizeNormal: 56,
    buttonSizeSmall: 40,
    buttonSizeIcon: iconSize * 2,
    textTransform: 'none',

    // Raied button
    raisedPrimaryHover: primaryColor3,
    raisedPrimaryBackgroundColor: primaryColor1,
    raisedPrimaryTextColor: _colors2.default.white,
    raisedAccentHover: accentColor3,
    raisedAccentBackgroundColor: accentColor1,
    raisedAccentTextColor: _colors2.default.white,

    // Flat Button
    flatBackgroundColor: 'transparent',
    flatTextColor: _colors2.default.white,
    flatPrimaryHover: _colors2.default.grey300,
    flatPrimaryBackgroundColor: 'transparent',
    flatPrimaryTextColor: primaryColor1,
    flatAccentHover: _colors2.default.grey300,
    flatAccentBackgroundColor: 'transparent',
    flatAccentTextColor: accentColor1,

    // Icon Button
    iconPrimaryTextColor: primaryColor1,
    iconAccenttextColor: accentColor1,

    // Dark Button
    darkHover: _colors2.default.grey50,
    darkBackgroundColor: _colors2.default.darkBlack,
    darktextColor: _colors2.default.white,

    // Light Button
    lightHover: _colors2.default.grey300,
    lightBackgroundColor: _colors2.default.white,
    lightTextColor: _colors2.default.darkBlack,

    // Disabled
    disabledTextColor: _colors2.default.grey500
  },

  toggle: {
    toggleSize: '20px',
    checkboxSize: iconSize + 'px',
    checkedColor: primaryColor1,
    uncheckedColor: _colors2.default.white,
    thumbColorOff: _colors2.default.white,
    thumbColorOn: primaryColor1,
    trackColorOff: _colors2.default.white,
    trackColorOn: 'fade-out(' + primaryColor1 + ', 0.5)',
    transition: 'opacity 450ms ' + easeOutFunction + ' 0ms, transform 0ms ' + easeOutFunction + ' 450ms',
    transitionCheckOn: 'opacity 0ms ' + easeOutFunction + ' 0ms, transform 800ms ' + easeOutFunction + ' 0ms',
    easeOutBoxOn: 'all 100s ' + easeOutFunction + ' 0ms',
    easeOutIconBox: 'all 2s ' + easeOutFunction + ' 200ms',
    easeOutDefault: easeOutDefault
  },

  tabs: {
    textColor: _colors2.default.white,
    backgroundColor: primaryColor1,
    secondaryTextColor: _colors2.default.white,
    secondaryActiveTextColor: _colors2.default.white,
    easeOutInkBar: 'left 1s ' + easeOutFunction + ' 0ms'
  },

  avatar: {
    backgroundColor: _colors2.default.grey500,
    color: _colors2.default.white,
    selectedColor: primaryColor1,
    selectedBackgroundColor: primaryColor3
  },

  paper: {
    backgroundColorDepth1: '#252526',
    boxShadowDepth1: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth1Bottom: 'none',
    backgroundColorDepth2: '#1e1e1e',
    boxShadowDepth2: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth2Bottom: 'none',
    backgroundColorDepth3: '#131313',
    boxShadowDepth3: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth3Bottom: 'none',
    backgroundColorDepth4: '#0e0e0e',
    boxShadowDepth4: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth4Bottom: 'none',
    backgroundColorDepth5: '#000000',
    boxShadowDepth5: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth5Bottom: 'none'
  }
};

exports.default = modern;
module.exports = exports['default'];