'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTheme = undefined;

var _themes = require('./themes');

var _uaParserJs = require('ua-parser-js');

var _uaParserJs2 = _interopRequireDefault(_uaParserJs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Auto select the theme based on the user agent
 *
 * @param {Object} uaParserArg Optional parser to use rather than newing up one
 */
var getTheme = exports.getTheme = function getTheme() {
  var uaParserArg = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

  var uaParser = uaParserArg || new _uaParserJs2.default();

  // If we can get the OS then try and auto-detect
  if (uaParser.getOS() && uaParser.getOS().name) {
    var currentOS = uaParser.getOS().name.toLowerCase();

    switch (currentOS) {
      case 'windows phone':
      case 'windows mobile':
      case 'windows':
        {
          return _themes.modern;
        }
      case 'osx':
      case 'mac os':
      case 'ios':
        {
          return _themes.human;
        }
      case 'linux':
      case 'android':
        {
          return _themes.material;
        }
    }
  }

  // Default to material if nothing was found
  return _themes.material;
};