'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withoutTransition = exports.forceRedraw = exports.toggleClass = exports.hasClass = exports.removeClass = exports.addClass = exports.scrollOffset = exports.offsetAbsolute = exports.offset = exports.isDescendant = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isDescendant = exports.isDescendant = function isDescendant(parent, child) {
  var node = child.parentNode;

  while (node != null) {
    if (node == parent) return true;
    node = node.parentNode;
  }

  return false;
};

var offset = exports.offset = function offset(el) {
  var rect = el.getBoundingClientRect();
  var documentOffset = scrollOffset();

  // Set simple points
  var points = {
    top: rect.top + documentOffset.top,
    left: rect.left + documentOffset.left,
    bottom: rect.bottom + documentOffset.top,
    right: rect.right + documentOffset.left,
    width: rect.width,
    height: rect.bottom - rect.top
  };

  // Add a couple computed points from the simple
  points.middle = points.top + points.height / 2;
  points.center = points.left + points.width / 2;

  return points;
};

/**
 * Get the cumulative absolute offset of an element
 */
var offsetAbsolute = exports.offsetAbsolute = function offsetAbsolute(element) {
  var top = 0,
      left = 0;
  do {
    top += element.offsetTop || 0;
    left += element.offsetLeft || 0;
    element = element.offsetParent;
  } while (element);

  return {
    top: top,
    left: left
  };
};

var scrollOffset = exports.scrollOffset = function scrollOffset(el) {
  // If we passed an element, return scroll positions of the element
  if (el) {
    return {
      top: el.scrollTop,
      left: el.scrollLeft
    };
  }

  // Try to get the body
  var doc = document.documentElement;
  var left = (window.pageXOffset || doc.scrollLeft) - (doc.clientLeft || 0);
  var top = (window.pageYOffset || doc.scrollTop) - (doc.clientTop || 0);
  return { top: top, left: left };
};

var addClass = exports.addClass = function addClass(el, className) {
  if (el.classList) el.classList.add(className);else el.className += ' ' + className;
};

var removeClass = exports.removeClass = function removeClass(el, className) {
  if (el.classList) el.classList.remove(className);else el.className = el.className.replace(new RegExp('(^|\\b)' + className.split(' ').join('|') + '(\\b|$)', 'gi'), ' ');
};

var hasClass = exports.hasClass = function hasClass(el, className) {
  if (el.classList) return el.classList.contains(className);else return new RegExp('(^| )' + className + '( |$)', 'gi').test(el.className);
};

var toggleClass = exports.toggleClass = function toggleClass(el, className) {
  if (hasClass(el, className)) removeClass(el, className);else addClass(el, className);
};

var forceRedraw = exports.forceRedraw = function forceRedraw(el) {
  var originalDisplay = el.style.display;

  el.style.display = 'none';
  el.offsetHeight;
  el.style.display = originalDisplay;
};

var withoutTransition = exports.withoutTransition = function withoutTransition(el, callback) {
  // We only need to do this if el.style was set
  // it is almost never set for unit tests or server-side rendering
  if (typeof el.style === 'undefined') {
    callback();
    return;
  }

  //turn off transition
  el.style.transition = 'none';

  callback();

  //force a redraw
  forceRedraw(el);

  //put the transition back
  el.style.transition = '';
};

exports.default = {
  isDescendant: isDescendant,
  offset: offset,
  offsetAbsolute: offsetAbsolute,
  scrollOffset: scrollOffset,
  addClass: addClass,
  removeClass: removeClass,
  hasClass: hasClass,
  toggleClass: toggleClass,
  forceRedraw: forceRedraw,
  withoutTransition: withoutTransition
};