import React from 'react';
import PropTypes from 'prop-types';
import IconButton from '../Button/IconButton';

/**
 * Wrapper for an IconButton in the AppBar
 *
 * @param props
 * @returns {ReactDOM}
 */
const AppBarIconButton = props => {
  // Get className and children, and put the rest in other to forward below
  let { className, children, ...other } = props;

  // TODO: If we need to add a class to the button we can do it here

  return (
    <IconButton className={className} {...other}>
      {children}
    </IconButton>
  );
};

/**
 * Set accepted properties
 */
AppBarIconButton.propTypes = {
  /**
   * Optional class override
   */
  className: PropTypes.string,

  /**
   * Child elements (text and icon)
   */
  children: PropTypes.node,
};

/**
 * Set property defaults
 */
AppBarIconButton.defaultProps = {
  className: '',
  children: null,
};

export default AppBarIconButton;
