import React from 'react';
import PropTypes from 'prop-types';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

const Avatar = props => {
  let children = null;
  if (props.src) {
    // Add the image to the avatar
    children = <img alt={props.alt} src={props.src} className={props.classes.img} />;
  } else if (props.icon) {
    children = props.icon;
  } else {
    children = props.iconLetters;
  }

  let classes = props.classes.avatar;
  if (props.selected) {
    classes += ' ' + props.classes.selected;
  }

  return (
    <div className={classes} style={props.style} onClick={props.onClick}>
      {children}
    </div>
  );
};

/**
 * Set property defaults
 */
Avatar.defaultProps = {
  onClick: null,
};

Avatar.propTypes = {
  /**
   * JSS classes for styling the component
   */
  classes: PropTypes.object,

  /**
   * Used if avatar is an image
   */
  src: PropTypes.string,

  /**
   * Optional alt/title tag if using an image src
   */
  alt: PropTypes.string,

  /**
   * An SvgIcon to be used instead of src
   */
  icon: PropTypes.element,

  /**
   * Crate an avatar with letters like (FL) for Firstname Lastname
   */
  iconLetters: PropTypes.string,

  /**
   * Optional style overrides
   */
  style: PropTypes.object,

  /**
   * Indicate that the user has selected this avatar (change color)
   */
  selected: PropTypes.bool,

  /**
   * Callback function that is called when the div was clicked
   */
  onClick: PropTypes.func,
};

export default injectStyles(styles, Avatar);
