import React from 'react';
import PropTypes from 'prop-types';
import Button from './Button';

/**
 * Functional component for any flat button
 *
 * @param props
 * @returns {ReactDOM}
 * @constructor
 */
const FlatButton = props => {
  return (
    <Button type={'flat'} {...props}>
      {props.children}
    </Button>
  );
};

/**
 * Set accepted properties
 */
FlatButton.propTypes = {
  /**
   * Render any child components by default if label not passed by prop
   */
  children: PropTypes.node,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  href: PropTypes.string,
  icon: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  inverse: PropTypes.bool,
  label: PropTypes.string,
  onMouseLeave: PropTypes.func,
  onMouseUp: PropTypes.func,
  onTap: PropTypes.func,
  /**
   * Alias for onTap for backwards compatibility
   */
  onClick: PropTypes.func,
};

/**
 * Set property defaults
 */
FlatButton.defaultProps = {
  className: '',
};

export default FlatButton;
