export const styles = theme => ({
  // Default Button
  button: {
    userSelect: 'none',
    outline: 'none',
    border: 'none',
    position: 'relative',
    overflow: 'hidden',
    minHeight: theme.button.buttonHeight,
    minWidth: theme.button.buttonMinWidth,
    padding: '0 ' + theme.gutters.small + 'px',
    margin: '0 5px 0 0',
    textTransform: theme.button.textTransform,
    borderRadius: theme.button.buttonBorderRadius,
    boxSizing: 'border-box',
    fontFamily: theme.font.family,

    '&:focus': {
      outline: 'none',
      border: 'none',
    },
    '&:hover': {
      cursor: 'pointer',
    },
    '&:active': {
      outline: 'none',
      border: 'none',
    },
  },

  // Raised Button
  raised: {
    extend: 'button',
    color: theme.button.lightTextColor,
    backgroundColor: theme.button.lightBackgroundColor,
    boxShadow: theme.button.boxShadow,

    '&:hover': {
      backgroundColor: theme.button.lightHover,
    },
  },

  // Raised Primary
  raisedPrimary: {
    color: theme.button.raisedPrimaryTextColor,
    backgroundColor: theme.button.raisedPrimaryBackgroundColor,

    '&:hover': {
      backgroundColor: theme.button.raisedPrimaryHover,
    },
  },

  // Raised Accent
  raisedAccent: {
    color: theme.button.raisedAccentTextColor,
    backgroundColor: theme.button.raisedAccentBackgroundColor,

    '&:hover': {
      backgroundColor: theme.button.raisedAccentHover,
    },
  },

  // Disabled
  raisedDisabled: {
    color: theme.button.disabledTextColor,
    backgroundColor: theme.button.lightBackgroundColor,

    '&:hover': {
      backgroundColor: theme.button.lightBackgroundColor,
    },
  },

  // Flat Button
  flat: {
    extend: 'button',
    backgroundColor: theme.button.flatBackgroundColor,
    color: theme.button.flatTextColor,

    '&:hover': {
      backgroundColor: theme.button.lightHover,
    },
  },

  // Flat Primary
  flatPrimary: {
    color: theme.button.flatPrimaryTextColor,
  },

  // Flat Accent
  flatAccent: {
    color: theme.button.flatAccentTextColor,
  },

  // Disabled
  flatDisabled: {
    color: theme.button.disabledTextColor,

    '&:hover': {
      backgroundColor: 'transparent',
    },
  },

  // Floating Button
  floating: {
    extend: 'button',
    color: theme.button.lightTextColor,
    backgroundColor: theme.button.lightBackgroundColor,
    textAlign: 'center',
    verticalAlign: 'middle',
    height: theme.button.buttonSizeNormal + 'px',
    width: theme.button.buttonSizeNormal + 'px',
    minWidth: theme.button.buttonSizeNormal + 'px',
    boxShadow: '0 1px 4px ' + theme.button.boxShadow,
    borderRadius: theme.button.buttonSizeNormal / 2 + 'px',

    '&:hover': {
      backgroundColor: theme.button.darkHover,
    },
  },

  // Floating Mini
  floatingMini: {
    height: theme.button.buttonSizeSmall,
    width: theme.button.buttonSizeSmall,
    minWidth: theme.button.buttonSizeSmall,
    'border-radius': theme.button.buttonSizeSmall / 2 + 'px',
  },

  // Floating Depressed
  floatingDepressed: {
    boxShadow: '0 3px 10px ' + +theme.button.boxShadow,
  },

  // Floating Primary
  floatingPrimary: {
    color: theme.button.raisedPrimaryTextColor,
    backgroundColor: theme.button.raisedPrimaryBackgroundColor,

    '&:hover': {
      backgroundColor: theme.button.raisedPrimaryHover,
    },
  },

  // Floating Accent
  floatingAccent: {
    color: theme.button.raisedAccentTextColor,
    backgroundColor: theme.button.raisedAccentBackgroundColor,

    '&:hover': {
      backgroundColor: theme.button.raisedAccentHover,
    },
  },

  // Disabled
  floatingDisabled: {
    color: theme.button.disabledTextColor,
    backgroundColor: theme.button.lightBackgroundColor,
  },

  // Icon Button
  icon: {
    extend: 'button',
    backgroundColor: 'transparent',
    color: 'inherit',
    width: theme.button.buttonSizeIcon + 'px',
    height: theme.button.buttonSizeIcon + 'px',
    minWidth: theme.button.buttonSizeIcon + 'px',
    minHeight: theme.button.buttonSizeIcon + 'px',
    lineHeight: 'normal',
    padding: 0,
    margin: 0,

    '&:hover': {
      backgroundColor: 'transparent',
    },
  },

  iconPrimary: {
    color: theme.button.iconPrimaryTextColor,
    '&:hover': {
      backgroundColor: 'transparent',
    },
  },

  iconAccent: {
    color: theme.button.iconAccentTextColor,
    '&:hover': {
      backgroundColor: 'transparent',
    },
  },

  iconDisabled: {
    '&:hover': {
      backgroundColor: 'transparent',
    },
  },
});
