import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Functional component for any button
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
const FontIcon = (props, context) => {
  let { className, classes, ...other } = props;

  const classNames = classnames(
    classes.fontIcon,
    {
      [classes.iconSize18]: props.size == 18,
      [classes.iconSize24]: props.size == 24,
      [classes.iconSize36]: props.size == 36,
      [classes.iconSize48]: props.size == 48,
    },
    className,
  );

  // TODO: Set the material for now as default
  const themeName = 'material';
  const content = themeName === 'material' ? props.children : null;

  return (
    <span className={classNames} {...other}>
      {content}
    </span>
  );
};

/**
 * Set accepted properties
 */
FontIcon.propTypes = {
  className: PropTypes.string,
  size: PropTypes.oneOf([18, 24, 36, 48]),
};

/**
 * Set property defaults
 */
FontIcon.defaultProps = {
  className: '',
  size: 24,
};

// Wrap in JSS for styles
export default injectStyles(styles, FontIcon);
