import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Grid column
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
const Column = (props, context) => {
  const propsClasses = props.classes;

  const classes = classnames(propsClasses.column, {
    [propsClasses['colXSmall' + props.xsmall]]: props.xsmall,
    [propsClasses['colSmall' + props.small]]: props.small,
    [propsClasses['colMedium' + props.medium]]: props.medium,
    [propsClasses['colLarge' + props.large]]: props.large,
    [propsClasses['colXLarge' + props.xlarge]]: props.xlarge,
  });

  return (
    <div className={classes} style={props.style}>
      {props.children}
    </div>
  );
};

/**
 * Set accepted properties
 */
Column.propTypes = {
  xsmall: PropTypes.number,
  small: PropTypes.number,
  medium: PropTypes.number,
  large: PropTypes.number,
  xlarge: PropTypes.number,
  children: PropTypes.node,
  style: PropTypes.object,
};

// Wrap in JSS for styles
export default injectStyles(styles, Column);
