import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Grid row
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
const Container = (props, context) => {
  const classes = classnames(props.classes.container, {
    [props.classes.containerCentered]: props.centered,
    [props.classes.containerNoGutter]: props.nogutter,
  });

  return <div className={classes}>{props.children}</div>;
};

/**
 * Set accepted properties
 */
Container.propTypes = {
  /**
   * Child nodes to render
   * @ignore
   */
  children: PropTypes.node,

  /**
   * If true the remove gutters from the container
   */
  nogutter: PropTypes.bool,

  /**
   * Main centered contianer used for centering a full page
   */
  centered: PropTypes.bool,
};

Container.defaultProps = {
  nogutter: false,
  centered: false,
};

// Wrap in JSS for styles
export default injectStyles(styles, Container);
