/**
 * Create styles for each column class
 *
 * @param {int} cols
 * @param {int} outOfTotalCols
 */
const createColStyles = (cols, outOfTotalCols = 12) => {
  return {
    flex: '0 0 ' + (cols / outOfTotalCols) * 100 + '%',
    maxWidth: (cols / outOfTotalCols) * 100 + '%',
  };
};

export const styles = theme => {
  const mediaMedium = '@media (min-width: ' + theme.breakpoints.medium + 'px)';
  const mediaLarge = '@media (min-width: ' + theme.breakpoints.large + 'px)';
  const mediaxLarge = '@media (min-width: ' + theme.breakpoints.xLarge + 'px)';

  let classes = {
    container: {
      marginLeft: theme.gutters.small + 'px',
      marginRight: theme.gutters.small + 'px',
      boxSizing: 'border-box',
    },

    containerCentered: {
      [mediaMedium]: { width: '750px', marginLeft: 'auto', marginRight: 'auto' },
      [mediaLarge]: { width: '970px', marginLeft: 'auto', marginRight: 'auto' },
      [mediaxLarge]: { width: '1170px', marginLeft: 'auto', marginRight: 'auto' },
    },

    /**
     * Used to remove gutters from the container for nested grids
     */
    containerNoGutter: {
      marginRight: 0,
      marginLeft: 0,
    },

    row: {
      marginLeft: theme.gutters.small / -2 + 'px',
      marginRight: theme.gutters.small / -2 + 'px',
      boxSizing: 'border-box',
      display: 'flex',
      flexWrap: 'wrap',
    },

    column: {
      paddingLeft: theme.gutters.small / 2 + 'px',
      paddingRight: theme.gutters.small / 2 + 'px',
      minHeight: '1px',
      boxSizing: 'border-box',
      flex: 1,
    },

    /**
     * Horizontal gutter spacer to add spacing between row elements
     */
    gutterHoriz: {
      height: theme.gutters.small + 'px',
    },

    /**
     * Horizontal divider used to provide spacing between rows
     */
    dividerHoriz: {
      height: '1px',
      backgroundColor: theme.borderColor,
    },
  };

  // Small columns need to be printed first so they can be over-ridden below
  for (let cols = 1; cols <= 12; cols++) {
    classes['colSmall' + cols] = createColStyles(cols);
  }

  // Add medium columns
  for (let cols = 1; cols <= 12; cols++) {
    classes['colMedium' + cols] = {
      [mediaMedium]: createColStyles(cols),
    };
  }

  // Add large columns
  for (let cols = 1; cols <= 12; cols++) {
    classes['colLarge' + cols] = {
      [mediaLarge]: createColStyles(cols),
    };
  }

  // Add xlarge columns
  for (let cols = 1; cols <= 12; cols++) {
    classes['colXLarge' + cols] = {
      [mediaxLarge]: createColStyles(cols),
    };
  }

  return classes;
};
