export const styles = theme => {
  const mediaMedium = '@media (min-width: ' + theme.breakpoints.medium + 'px)';
  const mediaLarge = '@media (min-width: ' + theme.breakpoints.large + 'px)';
  const mediaxLarge = '@media (min-width: ' + theme.breakpoints.xLarge + 'px)';

  const styleBeforeAfter = {
    '&:before': {
      content: '" "',
      display: 'table',
    },
    '&:after': {
      content: '" "',
      display: 'table',
      clear: 'both',
    },
  };

  let gridObject = {
    container: Object.assign({}, styleBeforeAfter, {
      marginRight: 'auto',
      marginLeft: 'auto',
      paddingLeft: theme.gutters.small + 'px',
      paddingRight: theme.gutters.small + 'px',
      boxSizing: 'border-box',
      [mediaMedium]: { width: '750px' },
      [mediaLarge]: { width: '970px' },
      [mediaxLarge]: { width: '1170px' },
    }),

    containerFluid: Object.assign({}, styleBeforeAfter, {
      marginRight: 'auto',
      marginLeft: 'auto',
      paddingLeft: theme.gutters.small + 'px',
      paddingRight: theme.gutters.small + 'px',
      boxSizing: 'border-box',
    }),

    row: Object.assign({}, styleBeforeAfter, {
      marginLeft: '-' + theme.gutters.small + 'px',
      marginRight: '-' + theme.gutters.small + 'px',
      boxSizing: 'border-box',
    }),

    clearfix: styleBeforeAfter,

    centerBlock: {
      display: 'block',
      marginLeft: 'auto',
      marginRight: 'auto',
    },

    Pullright: {
      float: 'right !important',
    },

    Pullleft: {
      float: 'left !important',
    },

    hide: {
      display: 'none !important',
    },

    show: {
      display: 'block !important',
    },

    invisible: {
      visibility: 'hidden',
    },

    textHide: {
      font: '0/0 a',
      color: 'transparent',
      textShadow: 'none',
      'background-color': 'transparent',
      border: 0,
    },

    hidden: {
      display: 'none !important',
    },

    affix: {
      position: 'fixed',
    },
  };

  const columnStyle = {
    position: 'relative',
    minHeight: '1px',
    paddingLeft: theme.gutters.small + 'px',
    paddingRight: theme.gutters.small + 'px',
    boxSizing: 'border-box',
  };

  const colStyleValues = {
    '12': '100%',
    '11': '91.66666667%',
    '10': '83.33333333%',
    '9': '75%',
    '8': '66.66666667%',
    '7': '58.33333333%',
    '6': '50%',
    '5': '41.66666667%',
    '4': '33.33333333%',
    '3': '25%',
    '2': '16.66666667%',
    '1': '8.33333333%',
    '0': 'auto',
  };

  let colMedium = {};
  let colLarge = {};
  let colxLarge = {};

  /*
     * The Grid can be divided into a maximum of 12 columns.
     * We need to loop here 12 times to assign the specific width of each column
     */
  for (let idx = 0; idx <= 12; idx++) {
    let marginLeft = colStyleValues[idx];

    // We will be assigning styles here for the Grid Column 1 to 12
    if (idx > 0) {
      gridObject['colSmall' + idx] = Object.assign({}, columnStyle, {
        float: 'left',
        width: colStyleValues[idx],
      });
      gridObject['colMedium' + idx] = columnStyle;
      gridObject['colLarge' + idx] = columnStyle;
      gridObject['colXLarge' + idx] = columnStyle;

      colMedium['colMedium' + idx] = { float: 'left', width: colStyleValues[idx] };
      colLarge['colLarge' + idx] = { float: 'left', width: colStyleValues[idx] };
      colxLarge['colXLarge' + idx] = { float: 'left', width: colStyleValues[idx] };
    }

    // We will set the styles for pull/push/offset for columns when displaying in small devices
    gridObject['colSmallPull' + idx] = { right: colStyleValues[idx] };
    gridObject['colSmallPush' + idx] = { left: colStyleValues[idx] };
    gridObject['colSmalloffset-' + idx] = { marginLeft: marginLeft };

    // We will set the styles for pull/push/offset for columns when displaying in mediumn devices
    colMedium['colMediumPull' + idx] = { right: colStyleValues[idx] };
    colMedium['colMediumPush' + idx] = { left: colStyleValues[idx] };
    colMedium['colMediumoffset-' + idx] = { marginLeft: marginLeft };

    // We will set the styles for pull/push/offset for columns when displaying in large devices
    colLarge['colLargePull' + idx] = { right: colStyleValues[idx] };
    colLarge['colLargePush' + idx] = { left: colStyleValues[idx] };
    colLarge['colLargeoffset-' + idx] = { marginLeft: marginLeft };

    // We will set the styles for pull/push/offset for columns when displaying in xLarge devices
    colxLarge['colXLargePull' + idx] = { right: colStyleValues[idx] };
    colxLarge['colXLargePush' + idx] = { left: colStyleValues[idx] };
    colxLarge['colXLargeoffset-' + idx] = { marginLeft: marginLeft };
  }

  // Merge the styles for pull/push/offset (medium, large and xLarge devices)
  gridObject = Object.assign({}, gridObject, {
    [mediaMedium]: colMedium,
    [mediaLarge]: colLarge,
    [mediaxLarge]: colxLarge,
  });

  return gridObject;
};
