import React from 'react';
import PropTypes from 'prop-types';
import CloseIcon from '../icons/svg/CloseIcon';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Grouping Chip
 *
 * @param {Object} props
 * @returns {ReactDOM}
 * @constructor
 */
export const Chip = props => {
  const { children, deletable } = props;

  let classes = props.classes.chip || '';
  if (props.className) {
    classes += ' ' + props.className;
  }

  let displayDeleteButton = null;
  if (deletable) {
    displayDeleteButton = (
      <span className={props.classes.deletable} onClick={props.onDeleteClick}>
        <CloseIcon size={18} />
      </span>
    );
  }

  let displayChildren = children;
  if (typeof displayChildren === 'string') {
    displayChildren = <span>{children}</span>;
  }

  return (
    <div className={classes}>
      <div className={props.classes.chipChildren}>{displayChildren}</div>
      {displayDeleteButton}
    </div>
  );
};

/**
 * Set accepted properties
 */
Chip.propTypes = {
  /**
   * Optional class override
   */
  className: PropTypes.string,

  /**
   * JSS classes for styling the component
   */
  classes: PropTypes.object,

  /**
   * Child elements (text and icon)
   */
  children: PropTypes.node,

  /**
   * Flag that will determine if the grouping chip will be displaying the delete icon
   */
  deletable: PropTypes.bool,

  /**
   * Callback function that is called when clicking the delete icon
   */
  onDeleteClick: PropTypes.func,
};

// Wrap in JSS for styles
export default injectStyles(styles, Chip);
