export const styles = theme => ({
  textField: {
    fontSize: '16px',
    lineHeight: '24px',
    display: 'block',
    position: 'relative',
    padding: '20px 0 20px 0',
    transition: theme.input.transition,
  },

  textFieldWithoutFloatingText: {
    padding: '0px',
  },

  label: {
    position: 'absolute',
    color: theme.input.colorScheme.disabledTextColor,
    opacity: 1,
    marginTop: '2px',
    fontWeight: 'normal',
    cursor: 'text',
    transition: theme.input.easeOutDefault,
  },

  hint: {
    extend: 'label',
  },

  hintDisabled: {
    color: theme.input.colorScheme.disabledTextColor,
  },

  hintHasValue: {
    opacity: 0,
  },

  errorText: {
    position: 'absolute',
    bottom: '-10px',
    fontSize: '12px',
    lineHeight: '12px',
    color: theme.input.colorScheme.errorTextColor,
    transition: theme.input.easeOutDefault,
  },

  input: {
    position: 'relative',
    width: '100%',
    margin: '6px 0 6px 0',
    padding: 0,
    border: 'none',
    outline: 'none',
    backgroundColor: 'transparent',
    color: theme.input.colorScheme.bodyTextColor,
  },

  inputDisabled: {
    color: theme.input.colorScheme.disabledTextColor,
  },

  textarea: {
    /* textareas have 3px height added to input */
    margin: '2px 0 6px 0',
    padding: 0,
    width: '100%',
    border: 'none',
    outline: 'none',
    resize: 'none',
    backgroundColor: 'transparent',
    color: theme.input.colorScheme.bodyTextColor,
  },

  textareaDisabled: {
    extend: 'inputDisabled',
  },

  /*
   * Underlines
   */
  unfocusUnderline: {
    position: 'relative',
    width: '100%',
    margin: 0,
    height: '1px',
    backgroundColor: theme.input.colorScheme.disabledTextColor,
  },

  focusUnderline: {
    marginTop: '-1px',
    backgroundColor: theme.input.colorScheme.primaryColor,
    height: '2px',
    transform: theme.input.scale.zero,
    transition: theme.input.easeOutDefault,
  },

  focusUnderlineOn: {
    transform: theme.input.scale.one,
  },

  focusUnderlineError: {
    borderColor: theme.input.colorScheme.errorTextColor,
    transform: theme.input.scale.one,
    transition: theme.input.easeOutDefault,
  },

  focusUnderLineDisabled: {
    border: 'none',
    height: '40px',
    overflow: 'hidden',

    //hack because border style dotted just doesn't look right
    //border-bottom-style: dotted,
    '&:after': {
      content:
        "'..............................................................................................................................................................................................................................................................................................................................................................'",
      position: 'absolute',
      top: '23px',
      color: theme.input.colorScheme.disabledTextColor,
    },
  },

  //Floating Label Text Field Styles
  //--------------------------------
  floatingLabel: {
    extend: 'label',
    transform: theme.input.scale.default,
    transformOrigin: 'left top',
  },

  floatingLabelFloated: {
    transform: theme.input.scale.float,
    color: theme.input.colorScheme.primaryColor,
  },

  floatingLabelError: {
    color: theme.input.colorScheme.errorTextColor,
  },

  floatingLabelDisabled: {
    color: theme.input.colorScheme.disabledTextColor,
  },

  richText: {
    marginTop: '10px',
    cursor: 'text',
    minHeight: '100px',
  },

  richTextContainer: {
    borderTop: '1px solid #ddd',
  },

  autoCompleteContainer: {
    position: 'absolute',
  },

  richTextBlockQuote: {
    color: theme.input.blockQuoteTextColor,
    fontStyle: 'italic',
    textAlign: 'center',
  },

  richTextDefaultBlock: {
    marginBottom: '15px',
  },

  /**
   * Generated with:
   *  npm install -g jss-cli
   *  jss convert ../../node_modules/draft-js/dist/Draft.css js > draft-js.style.js
   *  Copy the contents below
   */
  '@global': {
    '.DraftEditor-editorContainer, .DraftEditor-root, .public-DraftEditor-content': {
      height: 'inherit',
      textAlign: 'initial',
    },
    '.public-DraftEditor-content[contenteditable=true]': {
      W: 'read-write-plaintext-only',
    },
    '.DraftEditor-root': {
      position: 'relative',
    },
    '.DraftEditor-editorContainer': {
      backgroundColor: 'rgba(255,255,255,0)',
      borderLeft: '.1px solid transparent',
      position: 'relative',
      zIndex: '1',
    },
    '.public-DraftEditor-block': {
      position: 'relative',
    },
    '.DraftEditor-alignLeft .public-DraftStyleDefault-block': {
      textAlign: 'left',
    },
    '.DraftEditor-alignLeft .public-DraftEditorPlaceholder-root': {
      left: '0',
      textAlign: 'left',
    },
    '.DraftEditor-alignCenter .public-DraftStyleDefault-block': {
      textAlign: 'center',
    },
    '.DraftEditor-alignCenter .public-DraftEditorPlaceholder-root': {
      margin: '0 auto',
      textAlign: 'center',
      width: '100%',
    },
    '.DraftEditor-alignRight .public-DraftStyleDefault-block': {
      textAlign: 'right',
    },
    '.DraftEditor-alignRight .public-DraftEditorPlaceholder-root': {
      right: '0',
      textAlign: 'right',
    },
    '.public-DraftEditorPlaceholder-root': {
      color: '#9197a3',
      position: 'absolute',
      zIndex: '1',
    },
    '.public-DraftEditorPlaceholder-hasFocus': {
      color: '#bdc1c9',
    },
    '.DraftEditorPlaceholder-hidden': {
      display: 'none',
    },
    '.public-DraftStyleDefault-block': {
      position: 'relative',
      whiteSpace: 'pre-wrap',
    },
    '.public-DraftStyleDefault-ltr': {
      direction: 'ltr',
      textAlign: 'left',
    },
    '.public-DraftStyleDefault-rtl': {
      direction: 'rtl',
      textAlign: 'right',
    },
    '.public-DraftStyleDefault-listLTR': {
      direction: 'ltr',
    },
    '.public-DraftStyleDefault-listRTL': {
      direction: 'rtl',
    },
    '.public-DraftStyleDefault-ol, .public-DraftStyleDefault-ul': {
      margin: '16px 0',
      padding: '0',
    },
    '.public-DraftStyleDefault-depth0.public-DraftStyleDefault-listLTR': {
      marginLeft: '1.5em',
    },
    '.public-DraftStyleDefault-depth0.public-DraftStyleDefault-listRTL': {
      marginRight: '1.5em',
    },
    '.public-DraftStyleDefault-depth1.public-DraftStyleDefault-listLTR': {
      marginLeft: '3em',
    },
    '.public-DraftStyleDefault-depth1.public-DraftStyleDefault-listRTL': {
      marginRight: '3em',
    },
    '.public-DraftStyleDefault-depth2.public-DraftStyleDefault-listLTR': {
      marginLeft: '4.5em',
    },
    '.public-DraftStyleDefault-depth2.public-DraftStyleDefault-listRTL': {
      marginRight: '4.5em',
    },
    '.public-DraftStyleDefault-depth3.public-DraftStyleDefault-listLTR': {
      marginLeft: '6em',
    },
    '.public-DraftStyleDefault-depth3.public-DraftStyleDefault-listRTL': {
      marginRight: '6em',
    },
    '.public-DraftStyleDefault-depth4.public-DraftStyleDefault-listLTR': {
      marginLeft: '7.5em',
    },
    '.public-DraftStyleDefault-depth4.public-DraftStyleDefault-listRTL': {
      marginRight: '7.5em',
    },
    '.public-DraftStyleDefault-unorderedListItem': {
      listStyleType: 'square',
      position: 'relative',
    },
    '.public-DraftStyleDefault-unorderedListItem.public-DraftStyleDefault-depth0': {
      listStyleType: 'disc',
    },
    '.public-DraftStyleDefault-unorderedListItem.public-DraftStyleDefault-depth1': {
      listStyleType: 'circle',
    },
    '.public-DraftStyleDefault-orderedListItem': {
      listStyleType: 'none',
      position: 'relative',
    },
    '.public-DraftStyleDefault-orderedListItem.public-DraftStyleDefault-listLTR:before': {
      left: -36,
      position: 'absolute',
      textAlign: 'right',
      width: 30,
    },
    '.public-DraftStyleDefault-orderedListItem.public-DraftStyleDefault-listRTL:before': {
      position: 'absolute',
      right: -36,
      textAlign: 'left',
      width: 30,
    },
    '.public-DraftStyleDefault-orderedListItem:before': {
      content: 'counter(ol0) ". "',
      counterIncrement: 'ol0',
    },
    '.public-DraftStyleDefault-orderedListItem.public-DraftStyleDefault-depth1:before': {
      content: 'counter(ol1) ". "',
      counterIncrement: 'ol1',
    },
    '.public-DraftStyleDefault-orderedListItem.public-DraftStyleDefault-depth2:before': {
      content: 'counter(ol2) ". "',
      counterIncrement: 'ol2',
    },
    '.public-DraftStyleDefault-orderedListItem.public-DraftStyleDefault-depth3:before': {
      content: 'counter(ol3) ". "',
      counterIncrement: 'ol3',
    },
    '.public-DraftStyleDefault-orderedListItem.public-DraftStyleDefault-depth4:before': {
      content: 'counter(ol4) ". "',
      counterIncrement: 'ol4',
    },
    '.public-DraftStyleDefault-depth0.public-DraftStyleDefault-reset': {
      counterReset: 'ol0',
    },
    '.public-DraftStyleDefault-depth1.public-DraftStyleDefault-reset': {
      counterReset: 'ol1',
    },
    '.public-DraftStyleDefault-depth2.public-DraftStyleDefault-reset': {
      counterReset: 'ol2',
    },
    '.public-DraftStyleDefault-depth3.public-DraftStyleDefault-reset': {
      counterReset: 'ol3',
    },
    '.public-DraftStyleDefault-depth4.public-DraftStyleDefault-reset': {
      counterReset: 'ol4',
    },
  },
});
