import React, { Children } from 'react';
import PropTypes from 'prop-types';

/**
 * Functional component for any button
 *
 * @param props
 * @returns {ReactDOM}
 * @constructor
 */
const List = props => {
  let currentIndex = 0;
  let childElements = Children.map(props.children, child => {
    let retChild = child;
    if (React.isValidElement(child) && props.selectable) {
      retChild = React.cloneElement(child, {
        selected: props.selectedIndex === currentIndex,
      });
    }

    // Increment index to keep track of selected
    currentIndex++;

    return retChild;
  });

  return <div>{childElements}</div>;
};

/**
 * Set accepted properties
 */
List.propTypes = {
  /**
   * Child nodes
   */
  children: PropTypes.node,

  /**
   * Can the user select an item from the list
   */
  selectable: PropTypes.bool,

  /**
   * Optional currently selected index if selectable
   */
  selectedIndex: PropTypes.number,
};

/**
 * Set property defaults
 */
List.defaultProps = {
  selectable: false,
  selectedIndex: null,
};

export default List;
