import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Show a divider (hr) in a list
 *
 * @param props
 * @returns {ReactDOM}
 */
const ListDivider = props => {
  let classes = classnames(props.classes.listDivider, {
    [props.classes.listDividerInset]: props.inset,
  });

  return <div className={classes} />;
};

/**
 * Set accepted properties
 */
ListDivider.propTypes = {
  /**
   * Optional flag that can be set to indicate this item is selected
   */
  inset: PropTypes.bool,

  /**
   * JSS classes for styling the component
   */
  classes: PropTypes.object,
};

/**
 * Set property defaults
 */
ListDivider.defaultProps = {
  inset: false,
};

export default injectStyles(styles, ListDivider);
