import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import Checkbox from '../Toggle/Checkbox';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Functional component for any button
 *
 * @param props
 * @returns {ReactDOM}
 * @constructor
 */
const ListItemCheckbox = props => {
  let classes = classnames(props.classes.listItem, {
    [props.classes.listItemSelected]: props.checked,
  });

  // Create a change function to call in case the user did not pass one
  const onChange = (e, checked) => {
    if (props.onChange) {
      props.onChange(e, checked);
    }
  };

  // If we have a right element add it
  const rightElement = props.rightElement ? (
    <div className={props.classes.listItemRight}>{props.rightElement}</div>
  ) : null;

  return (
    <div className={classes}>
      <div className={props.classes.listItemContent}>
        <div className={props.classes.listItemLeft}>
          <Checkbox onChange={onChange} checked={props.checked} />
        </div>
        <div
          className={props.classes.listItemData}
          onClick={e => {
            onChange(e, !props.checked);
          }}
        >
          <div className={props.classes.listItemPrimary}>{props.primaryText}</div>
          <div className={props.classes.listItemSecondary}>{props.secondaryText}</div>
        </div>
        {rightElement}
      </div>
    </div>
  );
};

/**
 * Set accepted properties
 */
ListItemCheckbox.propTypes = {
  /**
   * Primary text/title of the item
   */
  primaryText: PropTypes.string,

  /**
   * Secondary text for the item - often a snippet of the body
   */
  secondaryText: PropTypes.string,

  /**
   * Node element to render on the right side
   */
  rightElement: PropTypes.node,

  /**
   * Event called when we select the control
   */
  onChange: PropTypes.func,

  /**
   * Bool to set whether or not this element is checked
   */
  checked: PropTypes.bool,

  /**
   * JSS classes for styling the component
   */
  classes: PropTypes.object,
};

/**
 * Set property defaults
 */
ListItemCheckbox.defaultProps = {
  primaryText: null,
  secondaryText: null,
  leftElement: null,
  rightElement: null,
  checked: false,
};

export default injectStyles(styles, ListItemCheckbox);
