import React, { Component } from 'react';
import PropTypes from 'prop-types';
import FontIcon from '../FontIcon/FontIcon';
import Toggle from '../Toggle/Switch';
import classnames from 'classnames';
import { menuItemTypes } from './menuItemTypes';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

class MenuItem extends Component {
  static Types = menuItemTypes;

  render() {
    const propsClasses = this.props.classes;

    const classes = classnames(propsClasses.menuItem, {
      [propsClasses.menuItemSelected]: this.props.selected,
      [propsClasses.menuItemFocused]: this.props.focused,
      [propsClasses.menuItemDisabled]: this.props.disabled,
    });
    let icon = this.props.icon;
    let data;
    let iconRight;
    let attribute;
    let number;
    let toggle;

    if (this.props.iconClassName) {
      icon = <FontIcon className={propsClasses.menuItemIcon + ' ' + this.props.iconClassName} />;
    }
    if (this.props.iconRightClassName) {
      iconRight = (
        <FontIcon
          className={propsClasses.menuItemIconRight + ' ' + this.props.iconRightClassName}
        />
      );
    }
    if (this.props.data) {
      data = <span className={propsClasses.menuItemData}>{this.props.data}</span>;
    }
    if (this.props.number !== undefined) {
      number = <span className={propsClasses.menuItemNumber}>{this.props.number}</span>;
    }
    if (this.props.attribute !== undefined) {
      attribute = <span className={propsClasses.menuItemAttribute}>{this.props.attribute}</span>;
    }

    // Add indentations for hierarchical menus
    const numIndents = this.props.indent || 0;
    let indentItems = numIndents ? [] : null;
    for (let i = 0; i < numIndents; i++) {
      indentItems.push(
        <span className={propsClasses.menuItemIndent} key={i}>
          {' '}
        </span>,
      );
    }

    if (this.props.toggle) {
      let { toggle, onClick, onToggle, children, label, ...other } = this.props;
      toggle = <Toggle {...other} onChange={this._handleToggle} />;
    }

    return (
      <div key={this.props.index} className={classes} onClick={this._handleOnClick}>
        {indentItems}
        {icon}
        {this.props.children}
        {data}
        {attribute}
        {number}
        {toggle}
        {iconRight}
      </div>
    );
  }

  _handleTouchTap = e => {
    if (!this.props.disabled && this.props.onClick) {
      this.props.onClick(e, this.props.index);
    } else if (!this.props.disabled && this.props.onClick) {
      this._handleOnClick(e);
    }
  };

  _handleOnClick = e => {
    if (!this.props.disabled && this.props.onClick) this.props.onClick(e, this.props.index);
  };

  _handleToggle = (e, toggled) => {
    if (!this.props.disabled && this.props.onToggle)
      this.props.onToggle(e, this.props.index, toggled);
  };
}

/**
 * Set accepted properties
 */
MenuItem.propTypes = {
  index: PropTypes.number,
  iconClassName: PropTypes.string,
  iconRightClassName: PropTypes.string,
  attribute: PropTypes.string,
  number: PropTypes.string,
  data: PropTypes.string,
  toggle: PropTypes.bool,
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  selected: PropTypes.bool,
  indent: PropTypes.number,
};

/**
 * Set property defaults
 */
MenuItem.defaultProps = {
  toggle: false,
  disabled: false,
  index: -1,
  icon: null,
};

// Wrap in JSS for styles
export default injectStyles(styles, MenuItem);
