import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

class Overlay extends Component {
  /**
   * Set accepted properties
   */
  static propTypes = {
    show: PropTypes.bool,
    onClick: PropTypes.func,

    /**
     * JSS classes
     */
    classes: PropTypes.object,
  };

  /**
   * Set property defaults
   */
  static defaultProps = {
    show: false,
  };

  componentDidMount() {
    this.setBodyOverflow();
  }

  componentWillUnmount() {
    const OVERFLOW_AUTOMATIC = '';
    this.setBodyOverflow(OVERFLOW_AUTOMATIC);
  }

  componentDidUpdate() {
    this.setBodyOverflow();
  }

  render() {
    const { className, ...other } = this.props,
      classes = classnames(
        this.props.classes.overlay,
        {
          [this.props.classes.overlayVisible]: this.props.show,
        },
        className,
      );

    return <div className={classes} onClick={this.props.onClick} />;
  }

  /**
   * Function that will set the overflow the the html body
   *
   * @param {string} forceOverflowValue Optional. This will override the overflow value and will be set directly to body's overflow.
   */
  setBodyOverflow(forceOverflowValue) {
    // We need to make sure that the document is mounted before we set the overflow
    if (document) {
      const body = document.getElementsByTagName('body')[0];
      let overflowValue = this.props.show ? 'hidden' : '';

      // if force overflow value is defined, then we will use it to set the body's overflow
      if (typeof forceOverflowValue !== "undefined") {
        overflowValue = forceOverflowValue;
      }

      body.style.overflow = overflowValue;
    }
  }
}

// Wrap in JSS for styles
export default injectStyles(styles, Overlay);
