/**
 * Paper is a concept taken from google Material design standards
 */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Small application component
 */
class Paper extends Component {
  /**
   * Set accepted properties
   */
  static propTypes = {
    circle: PropTypes.bool,
    innerClassName: PropTypes.string,
    rounded: PropTypes.bool,
    style: PropTypes.object,
    zDepth: PropTypes.oneOf([0, 1, 2, 3, 4, 5]),
  };

  /**
   * Set property defaults
   */
  static defaultProps = {
    innerClassName: '',
    rounded: true,
    zDepth: 1,
    style: null,
  };

  componentDidMount() {
    // Variables used for callback refs
    this.innerContainer = null;
  }

  render() {
    const propsClasses = this.props.classes;
    let classes = propsClasses.paper;

    if (this.props.className) {
      classes += ' ' + this.props.className;
    }

    classes += ' ' + propsClasses['paperZDepth' + this.props.zDepth];

    if (this.props.rounded) {
      classes += ' ' + propsClasses.paperRounded;
    }

    if (this.props.circle) {
      classes += ' ' + propsClasses.paperCircle;
    }

    const insideClasses =
      this.props.innerClassName +
      ' ' +
      propsClasses.paperContainer +
      ' ' +
      propsClasses['paperZDepth' + this.props.zDepth + 'Bottom'];

    return (
      <div
        className={classes}
        style={this.props.style}
        ref={innerContainer => {
          this.innerContainer = innerContainer;
        }}
      >
        {this.props.children}
      </div>
    );
  }

  getInnerContainer() {
    return this.innerContainer;
  }
}

// Wrap in JSS for styles
export default injectStyles(styles, Paper);
