import React, { Component } from 'react';
import PropTypes from 'prop-types';
import TouchRipple from '../ripples/TouchRipple';
import FocusRipple from '../ripples/FocusRipple';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Functional component for any button
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
const RadioButton = (props, context) => {
  return (
    <label className={props.classes.radioButton}>
      <input
        type={'radio'}
        className={props.classes.radioButtonInput}
        name={props.name}
        value={props.value}
        checked={props.checked}
        onChange={e => {
          if (props.onSelect) {
            props.onSelect(props.value);
          }
        }}
      />
      {props.label}
    </label>
  );
};

/**
 * Set accepted properties
 */
RadioButton.propTypes = {
  className: PropTypes.string,
  disabled: PropTypes.bool,
  label: PropTypes.string,
  onSelect: PropTypes.func,
  checked: PropTypes.bool,

  /**
   * The value of the radio button
   */
  value: PropTypes.string,

  /**
   * Radio group name
   */
  name: PropTypes.string,
};

/**
 * Set property defaults
 */
RadioButton.defaultProps = {
  className: '',
  checked: false,
};

// Wrap in JSS for styles
export default injectStyles(styles, RadioButton);
