import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import FlatButton from '../Button/FlatButton';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Create a snackbar notice
 */
class Snackbar extends Component {
  static propTypes = {
    action: PropTypes.string,
    message: PropTypes.string.isRequired,
    open: PropTypes.bool,
    onActionClick: PropTypes.func,
    timeout: PropTypes.number,
    onDismiss: PropTypes.func,
  };

  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */
  constructor(props) {
    // Call parent constructor
    super(props);

    this.state = {
      open: this.props.open || false,
    };
  }

  componentDidUpdate(prevProps, prevState) {
    if (prevState.open != this.state.open && this.props.timeout) {
      if (this.timer) {
        clearTimeout(this.timer);
      }

      this.timer = setTimeout(() => {
        this.dismiss();
      }, this.props.timeout);
    }
  }

  componentDidMount() {
    if (this.props.open) {
      if (this.timer) {
        clearTimeout(this.timer);
      }
      this.timer = setTimeout(() => {
        this.dismiss();
      }, this.props.timeout);
    }
  }

  /**
   * Handle incoming new props
   */
  componentWillReceiveProps(nextProps) {
    this.setState({ open: nextProps.open || false });
  }

  render() {
    const propsClasses = this.props.classes;
    const classes = classnames(propsClasses.snackbar, {
      [propsClasses.snackbarIsOpen]: this.state.open,
    });
    let action;

    if (this.props.action) {
      action = (
        <FlatButton
          className={propsClasses.snackbarAction}
          label={this.props.action}
          onClick={this.props.onActionClick}
        />
      );
    }

    return (
      <span className={classes}>
        <span className={propsClasses.snackbarMessage}>{this.props.message}</span>
        {action}
      </span>
    );
  }

  dismiss() {
    if (this.state.open) {
      this.setState({ open: false });
    }

    if (this.props.onDismiss) {
      this.props.onDismiss();
    }
  }
}

// Wrap in JSS for styles
export default injectStyles(styles, Snackbar);
