import React from 'react';
import PropTypes from 'prop-types';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Get SVG icon
 *
 * @param {Object} props
 * @returns {JSX}
 */
const SvgIcon = props => {
  // Always use the default icon class and add optional extension class if passed
  let classNames = props.classes.icon;
  if (props.iconClass && props.classes[props.iconClass]) {
    classNames += ' ' + props.classes[props.iconClass];
  }

  const IconComponent = props.iconElement;
  return <IconComponent className={classNames} />;
};

/**
 * Accepted PropTypes
 */
SvgIcon.propTypes = {
  /**
   * JSS styles
   */
  classes: PropTypes.object,

  /**
   * Optional class to apply from ./styles.js
   */
  iconClass: PropTypes.string,

  /**
   * The icon component to render
   */
  iconElement: PropTypes.oneOfType([PropTypes.element, PropTypes.func]).isRequired,
};

/**
 * Set defaults
 */
SvgIcon.defaultProps = {
  iconClass: null,
};

// Wrap in JSS for styles
export default injectStyles(styles, SvgIcon);
