import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Render a tab
 */
class Tab extends Component {
  /**
   * Define the types of properties the component will receive
   */
  static propTypes = {
    handleTouchTap: PropTypes.func,
    selected: PropTypes.bool,

    /**
     * Secondary or inline tab
     */
    secondary: PropTypes.bool,
  };

  handleTouchTap = e => {
    this.props.handleTouchTap(this.props.tabIndex, this);
  };

  render() {
    const propsClasses = this.props.classes;
    const styles = { width: this.props.width };

    const classes = classnames(propsClasses.tabItem, {
      [propsClasses.tabItemIsActive]: this.props.selected,
      [propsClasses.tabItemSecondary]: this.props.secondary,
      [propsClasses.tabItemSecondaryIsActive]: this.props.selected && this.props.secondary,
    });

    return (
      <div className={classes} style={styles} onClick={this.handleTouchTap}>
        {this.props.label}
      </div>
    );
  }
}

// Wrap in JSS for styles
export default injectStyles(styles, Tab);
