import React from 'react';
import PropTypes from 'prop-types';
import { styles } from './textStyles';
import injectStyles from '../styles/injectStyles';

/**
 * Main body text
 *
 * @param {Object} props
 * @returns {Object}
 */
const BodyText = props => {
  return (
    <p style={props.style} className={props.classes.body}>
      {props.children}
    </p>
  );
};

/**
 * Accepted PropTypes
 */
BodyText.propTypes = {
  /**
   * JSS styles
   */
  classes: PropTypes.object,

  /**
   * Contents of the header
   */
  children: PropTypes.any,

  /**
   * Optional style overrides
   */
  style: PropTypes.object,
};

// Export an unstyled version for unit tests
export const BodyTextUnstyled = BodyText;

// Wrap in JSS for styles
export default injectStyles(styles, BodyText);
