import React from 'react';
import PropTypes from 'prop-types';
import { styles } from './textStyles';
import injectStyles from '../styles/injectStyles';

/**
 * Large alternate display header
 *
 * @param {Object} props
 * @returns {Object}
 */
const DisplayHeader = props => {
  return <h1 className={props.classes['display' + props.level]}>{props.children}</h1>;
};

/**
 * Accepted PropTypes
 */
DisplayHeader.propTypes = {
  /**
   * JSS styles
   */
  classes: PropTypes.object,

  /**
   * Contents of the header
   */
  children: PropTypes.any,

  /**
   * Levels 1-4 are supported
   */
  level: PropTypes.oneOf([1, 2, 3, 4]),
};

/**
 * Set sane defaults where needed
 */
DisplayHeader.defaultPropts = {
  level: 1,
};

// Wrap in JSS for styles
export default injectStyles(styles, DisplayHeader);
