import React from 'react';
import PropTypes from 'prop-types';
import { styles } from './textStyles';
import injectStyles from '../styles/injectStyles';

/**
 * Text header compontn
 *
 * @param {Object} props
 * @returns {Object}
 */
const Heading = props => {
  switch (props.level) {
    case 1: {
      return (
        <h1 style={props.style} className={props.classes.heading1}>
          {props.children}
        </h1>
      );
    }
    case 2: {
      return (
        <h2 style={props.style} className={props.classes.heading2}>
          {props.children}
        </h2>
      );
    }
    case 3: {
      return (
        <h3 style={props.style} className={props.classes.heading3}>
          {props.children}
        </h3>
      );
    }
    case 4:
    case 5:
    case 6: {
      return (
        <h4 style={props.style} className={props.classes.heading4}>
          {props.children}
        </h4>
      );
    }
  }
};

/**
 * Accepted PropTypes
 */
Heading.propTypes = {
  /**
   * JSS styles
   */
  classes: PropTypes.object,

  /**
   * Contents of the header
   */
  children: PropTypes.any,

  /**
   * Levels 1-4 are supported, but 5-6 are for h5-h6 HTML compat
   */
  level: PropTypes.oneOf([1, 2, 3, 4, 5, 6]),

  /**
   * Optional style overrides
   */
  style: PropTypes.object,
};

/**
 * Set sane defaults where needed
 */
Heading.defaultPropts = {
  level: 1,
};

// Export an unstyled version for unit tests
export const HeadingUnstyled = Heading;

// Wrap in JSS for styles
export default injectStyles(styles, Heading);
