import React from 'react';
import PropTypes from 'prop-types';
import Parser from 'html-react-parser';
import domToReact from 'html-react-parser/lib/dom-to-react';
import HeadingText from './HeadingText';
import BodyText from './BodyText';

/**
 * Local transform to convert html elements to chamel elements
 *
 * @param {Object} domNode Node we are transforming
 * @param {Object} parserOptions Passed from parent for recurrsive processing
 */
const transformHtmlToChamel = (domNode, parserOptions) => {
  if (domNode.type === 'tag') {
    switch (domNode.name) {
      case 'h1': {
        return <HeadingText level={1}>{domToReact(domNode.children, parserOptions)}</HeadingText>;
      }
      case 'h2': {
        return <HeadingText level={2}>{domToReact(domNode.children, parserOptions)}</HeadingText>;
      }
      case 'h3': {
        return <HeadingText level={3}>{domToReact(domNode.children, parserOptions)}</HeadingText>;
      }
      case 'h4': {
        return <HeadingText level={4}>{domToReact(domNode.children, parserOptions)}</HeadingText>;
      }
      case 'p': {
        return <BodyText>{domToReact(domNode.children, parserOptions)}</BodyText>;
      }
    }
  }
};

/**
 * Render an HTML string
 *
 * @param {Object} props
 * @returns {Object}
 */
const HtmlText = props => {
  const parserOptions = {
    replace: domNode => {
      // First check for custom transform
      if (props.transform) {
        const transformedComponent = props.transform(domNode);
        if (transformedComponent) {
          return transformedComponent;
        }
      }

      // Use standard transforms
      return transformHtmlToChamel(domNode, parserOptions);
    },
  };

  const sanitizedHtml = props.html.replace('<html>', '<div>').replace('</html>', '</div>');
  return <div>{Parser(sanitizedHtml, parserOptions)}</div>;
};

/**
 * Accepted PropTypes
 */
HtmlText.propTypes = {
  /**
   * JSS styles
   */
  classes: PropTypes.object,

  /**
   * Raw HTML string to render
   */
  html: PropTypes.string,
};

// Wrap in JSS for styles
export default HtmlText;
