import React from 'react';
import PropTypes from 'prop-types';
import { styles } from './textStyles';
import injectStyles from '../styles/injectStyles';
import ReactMarkdown from 'react-markdown';
import HeadingText from './HeadingText';
import BodyText from './BodyText';

/**
 * Map renderers to chameleon components where possible
 * See: https://github.com/rexxars/react-markdown/blob/master/src/renderers.js
 */
const renderComponts = {
  heading: HeadingText,
  p: BodyText,
};

/**
 * Render an HTML string
 *
 * @param {Object} props
 * @returns {Object}
 */
const HtmlText = props => {
  return <ReactMarkdown source={props.source} renderers={renderComponts} />;
};

/**
 * Accepted PropTypes
 */
HtmlText.propTypes = {
  /**
   * JSS styles
   */
  classes: PropTypes.object,

  /**
   * Raw string to render
   */
  source: PropTypes.string,
};

// Wrap in JSS for styles
export default injectStyles(styles, HtmlText);
