import React from 'react';
import TestRenderer from 'react-test-renderer';
import HtmlText from '../HtmlText';
import HeadingText, { HeadingUnstyled } from '../HeadingText';
import { BodyTextUnstyled } from '../BodyText';

describe('Text/HtmlText', () => {
  it('Should render', () => {
    const renderer = TestRenderer.create(<HtmlText html={'<h1>Heading</h1>'} />);
    expect(renderer.root.findByType(HtmlText)).not.toBeNull();
  });
  it('Should transform h1 to Text/Heading', () => {
    const renderer = TestRenderer.create(<HtmlText html={'<h1>Heading</h1>'} />);
    expect(renderer.root.findByType(HeadingUnstyled)).not.toBeNull();
  });
  it('Should transform h2 to Text/Heading', () => {
    const renderer = TestRenderer.create(<HtmlText html={'<h2>Heading</h2>'} />);
    expect(renderer.root.findByType(HeadingUnstyled)).not.toBeNull();
  });
  it('Should transform h3 to Text/Heading', () => {
    const renderer = TestRenderer.create(<HtmlText html={'<h3>Heading</h3>'} />);
    expect(renderer.root.findByType(HeadingUnstyled)).not.toBeNull();
  });
  it('Should transform h4 to Text/Heading', () => {
    const renderer = TestRenderer.create(<HtmlText html={'<h4>Heading</h4>'} />);
    expect(renderer.root.findByType(HeadingUnstyled)).not.toBeNull();
  });
  it('Should transform <p> to Text/Body', () => {
    const renderer = TestRenderer.create(<HtmlText html={'<p>body</p>'} />);
    expect(renderer.root.findByType(BodyTextUnstyled)).not.toBeNull();
  });
  it('Should prefer custom transform', () => {
    const renderer = TestRenderer.create(
      <HtmlText
        html={'<p>body</p>'}
        transform={domNode => {
          return <span>{'replaced'}</span>;
        }}
      />,
    );
    expect(renderer.root.findByType('span')).not.toBeNull();
  });
});
