import React from 'react';
import PropTypes from 'prop-types';
import TouchRipple from '../ripples/TouchRipple';
import FocusRipple from '../ripples/FocusRipple';
import CheckboxOutline from '../svg-icons/toggle-check-box-outline-blank';
import CheckboxChecked from '../svg-icons/toggle-check-box-checked';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Functional component for any button
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
const Checkbox = (props, context) => {
  const propsClasses = props.classes;
  const onTap =
    props.onChange && !props.disabled
      ? evt => {
          if (props.onChange) {
            props.onChange(evt, !props.checked);
          } else if (props.onCheck) {
            props.onCheck(evt, !props.checked);
          }
        }
      : null;

  let labelElement = null;
  if (props.label) {
    labelElement = <div className={propsClasses.checkboxText}>{props.label}</div>;
  }

  let outlineClasses = propsClasses.checkboxIconBox;
  if (props.checked) {
    outlineClasses += ' ' + propsClasses.checkboxIconBoxOn;
  }

  let checkClasses = propsClasses.checkboxIconCheck;
  if (props.checked) {
    checkClasses += ' ' + propsClasses.checkboxIconCheckOn;
  }

  return (
    <div onClick={onTap} className={propsClasses.checkbox}>
      <div className={propsClasses.checkboxIcon}>
        <CheckboxOutline className={outlineClasses} />
        <CheckboxChecked className={checkClasses} />
      </div>
      {labelElement}
    </div>
  );
};

/**
 * Set accepted properties
 */
Checkbox.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  label: PropTypes.string,

  /**
   * This is the function calling components should use to check status
   */
  onChange: PropTypes.func,

  /**
   * Legacy callback
   */
  onCheck: PropTypes.func,

  /**
   * Flag indicates whether or not the input box is checked
   */
  checked: PropTypes.bool,
};

/**
 * Set property defaults
 */
Checkbox.defaultProps = {
  className: '',
  checked: false,
};

// Wrap in JSS for styles
export default injectStyles(styles, Checkbox);
