import React from 'react';
import PropTypes from 'prop-types';
import TouchRipple from '../ripples/TouchRipple';
import FocusRipple from '../ripples/FocusRipple';
import Paper from '../Paper';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

/**
 * Switch toggle
 *
 * @param props
 * @param context
 * @returns {ReactDOM}
 * @constructor
 */
const Switch = (props, context) => {
  const propsClasses = props.classes;
  const onTap =
    props.onChange && !props.disabled
      ? evt => {
          if (props.onChange) {
            props.onChange(evt, !props.checked);
          }
        }
      : false;

  let labelElement = null;
  if (props.label) {
    labelElement = <div className={propsClasses.switchText}>{props.label}</div>;
  }

  let buttonClasses = propsClasses.switchIconButton;
  if (props.checked) {
    buttonClasses += ' ' + propsClasses.switchIconButtonOn;
  }

  let trackClasses = propsClasses.switchIconTrack;
  if (props.checked) {
    trackClasses += ' ' + propsClasses.switchIconTrackOn;
  }

  return (
    <div onClick={onTap} className={propsClasses.switch}>
      <div className={propsClasses.switchIcon}>
        <div className={trackClasses} />
        <Paper className={buttonClasses} zDepth={1} />
      </div>
      {labelElement}
    </div>
  );
};

/**
 * Set accepted properties
 */
Switch.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  disabled: PropTypes.bool,
  label: PropTypes.string,

  /**
   * This is the function calling components should use to check status
   */
  onChange: PropTypes.func,

  /**
   * Flag indicates whether or not the input box is checked
   */
  checked: PropTypes.bool,
};

/**
 * Set property defaults
 */
Switch.defaultProps = {
  className: '',
  checked: false,
};

// Wrap in JSS for styles
export default injectStyles(styles, Switch);
