import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { styles } from './styles';
import injectStyles from '../styles/injectStyles';

class FocusRipple extends Component {
  /**
   * Class constructor
   *
   * @param {Object} props Properties to send to the render function
   */
  constructor(props) {
    // Call paprent constructor
    super(props);

    this.node = React.createRef();
  }

  componentDidMount() {
    this.setRippleSize();
  }

  render() {
    const propsClasses = this.props.classes;
    let classes = classnames(propsClasses.rippleFocus, {
      [propsClasses.rippleShown]: this.props.show,
    });

    return (
      <div className={classes} ref={this.node}>
        <div className={propsClasses.rippleFocusInner} />
      </div>
    );
  }

  /**
   * Try and determine the size of the ripple based on the size of this dom element
   */
  setRippleSize() {
    if (!this.node.current) {
      return;
    }

    const el = this.node.current;
    const height = el.offsetHeight;
    const width = el.offsetWidth;
    const size = Math.max(height, width);

    // If element is mounted then set the size
    if (el.style) {
      el.style.height = size + 'px';
      el.style.top = (size / 2) * -1 + height / 2 + 'px';
    }
  }
}

/**
 * Set accepted properties
 */
FocusRipple.propTypes = {
  show: PropTypes.bool,
};

/**
 * Set property defaults
 */
FocusRipple.defaultProps = {
  show: false,
};

// Wrap in JSS for styles
export default injectStyles(styles, FocusRipple);
