import React, { Component } from 'react';
import ChamelThemeProvider from './ChamelThemeProvider';
import defaultTheme from './themes';
import injectSheet from 'react-jss';
import PropTypes from 'prop-types';

export default (stylesOrCreator, InnerComponent) => {
  const StyledInnerComponent = injectSheet(stylesOrCreator)(InnerComponent);

  return class ChamelStyleHOC extends Component {
    /**
     * Keep a reference to an InnerComponent for testing purposes
     */
    static InnerComponent = InnerComponent;

    /**
     * Check if the theme was already passed down
     */
    static contextTypes = {
      ['__THEMING__']: PropTypes.object,
    };

    /**
     * Make sure we call the parent constructor
     *
     * @param {Object} props
     * @param {Object} context
     */
    constructor(props, context) {
      super(props, context);
    }

    /**
     * Wrap the inner component
     */
    render() {
      // Pass all props down to the sytled inner component
      const props = {};
      Object.assign(props, this.props);

      // Check to see if theme is in context and wrap if not
      if (!this.context['__THEMING__']) {
        return (
          <ChamelThemeProvider theme={defaultTheme}>
            <StyledInnerComponent {...props} />
          </ChamelThemeProvider>
        );
      } else {
        return <StyledInnerComponent {...props} />;
      }
    }
  };
};
