import colors from './colors';

// The the primary and acceent colors for this theme
const primaryColor1 = colors.lightBlue500; // ios default = rgb(0, 122, 255)
const primaryColor3 = colors.lightBlue100;
const accentColor1 = colors.pinkA200;
const accentColor3 = colors.pinkA100;

const iconSize = 22;

/**
 * Gutters for spacing
 */
const gutters = {
  large: 16,
  medium: 12,
  small: 8,
};

/**
 * Theme matching apple iOS and OSX native components
 *
 * These variables will override the theme variables found in base
 * so it is only necessary to set properties that need to be different
 * than the base theme.
 */
export const human = {
  themeName: 'human',
  body: {
    backgroundColor: 'rgb(237, 237, 237)',
  },
  gutters,
  /**
   * AppBar variables
   */
  appBar: {
    heightSmall: '44px',
    heightMedium: '44px',
    heightLarge: '44px',
    centerConPadding: '0 ' + gutters.small + 'px 0 ' + gutters.small + 'px',
    title: {
      fontSize: '17px',
      fontWeight: '500',
      textAlign: 'left',
    },
    backgroundColor: primaryColor1,
    textColor: colors.darkWhite,
  },

  /**
   * Button variables
   */
  button: {
    buttonHeight: '44px',
    buttonMinWidth: '44px',
    buttonBorderRadius: '5px',
    boxShadow: 'none',
    buttonSizeNormal: 44,
    buttonSizeSmall: 32,
    buttonSizeIcon: iconSize * 2,
    textTransform: 'none',

    // Raised button
    raisedPrimaryHover: primaryColor3,
    raisedPrimaryBackgroundColor: primaryColor1,
    raisedPrimaryTextColor: colors.white,
    raisedAccentHover: accentColor3,
    raisedAccentBackgroundColor: accentColor1,
    raisedAccentTextColor: colors.white,

    // Flat Button
    flatPrimaryHover: colors.grey300,
    flatPrimaryBackgroundColor: colors.white,
    flatPrimaryTextColor: primaryColor1,
    flatAccentHover: colors.grey300,
    flatAccentBackgroundColor: colors.white,
    flatAccentTextColor: accentColor1,

    // Icon Button
    iconPrimaryTextColor: primaryColor1,
    iconAccenttextColor: accentColor1,

    // Dark Button
    darkHover: colors.grey50,
    darkBackgroundColor: colors.darkBlack,
    darktextColor: colors.white,

    // Light Button
    lightHover: colors.grey300,
    lightBackgroundColor: 'transparent',
    lightTextColor: colors.darkBlack,

    // Disabled
    disabledTextColor: colors.grey400,
  },

  /**
   * List
   */
  list: {
    itemHoverColor: 'rgba(0, 0, 0, .035)',
    itemPadding:
      gutters.medium +
      'px ' +
      gutters.small +
      'px ' +
      gutters.medium +
      'px ' +
      gutters.small +
      'px ',
    itemSelectedTextColor: primaryColor1,
    itemPrimaryColor: colors.darkBlack,
    itemSecondaryColor: colors.lightBlack,
    subHeaderPadding: gutters.medium,
  },

  table: {
    cellPadding: gutters.small + 'px',
  },

  font: {
    family:
      '-apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',

    display1: {
      size: '72px',
      weight: 200,
      color: 'rgba(0, 0, 0, 0.54)',
    },
    display2: {
      size: '40px',
      weight: 400,
      color: 'inherit',
    },
    display3: {
      size: '34px',
      weight: 400,
      color: 'inherit',
    },
    display4: {
      size: '28px',
      weight: 400,
      color: 'inherit',
    },
    heading1: {
      size: '26px',
      weight: 600,
      color: 'inherit',
    },
    heading2: {
      size: '22px',
      weight: 600,
      color: 'inherit',
    },
    heading3: {
      size: '20px',
      weight: 500,
      color: 'inherit',
    },
    heading4: {
      size: '17px',
      weight: 500,
      color: 'inherit',
    },
    body: {
      size: '17px',
      weight: 400,
      color: 'inherit',
    },
    lead: {
      size: '15px',
      weight: 400,
      color: 'inherit',
    },
    caption: {
      size: '12px',
      weight: 400,
      color: 'inherit',
    },
  },

  tabs: {
    height: '29px',
    fontSize: '13px',
    textColor: colors.black,
    activeTextColor: colors.white,
    backgroundColor: 'transparent',
    activeBackgroundColor: primaryColor1,
    secondaryTextColor: colors.black,
    secondaryActiveTextColor: colors.white,
    easeOutInkBar: 'none',
    tabsContainerBorder: '1px solid ' + primaryColor1,
    tabsContainerBorderRadius: '5px',
    inkBarBackgroundColor: 'transparent',
  },

  paper: {
    roundedBorderRadius: '0px',
    backgroundColorDepth1: '#ffffff',
    boxShadowDepth1: '0',
    boxShadowDepth1Bottom: 'none',
    borderDepth1: '1px solid #cccccc',
    backgroundColorDepth2: '#ffffff',
    boxShadowDepth2: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth2Bottom: 'none',
    borderDepth2: '0',
    backgroundColorDepth3: '#ffffff',
    boxShadowDepth3: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth3Bottom: 'none',
    borderDepth3: '0',
    backgroundColorDepth4: '#ffffff',
    boxShadowDepth4: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth4Bottom: 'none',
    borderDepth4: '0',
    backgroundColorDepth5: '#ffffff',
    boxShadowDepth5: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth5Bottom: 'none',
    borderDepth5: '0',
  },
};

export default human;
