import colors from './colors';

// The the primary and acceent colors for this theme
const primaryColor1 = '#007acc';
const primaryColor2 = '#005a97';
const primaryColor3 = '#9cdcfe';
const accentColor1 = colors.pinkA200;
const accentColor2 = colors.pinkA400;
const accentColor3 = colors.pinkA100;

const iconSize = 24;

// Transitions
const easeOutFunction = 'cubic-bezier(0.23, 1, 0.32, 1)';
const easeOutDefault = 'all 450ms ' + easeOutFunction + ' 0ms';

/**
 * Gutters for spacing
 */
const gutters = {
  large: 32,
  medium: 24,
  small: 16,
};

/**
 * Theme matching windows modern design
 *
 * These variables will override the theme variables found in base
 * so it is only necessary to set properties that need to be different
 * than the base theme.
 */
const modern = {
  themeName: 'modern',
  primaryColor1,
  primaryColor2,
  primaryColor3,
  accentColor1,
  accentColor2,
  accentColor3,

  /**
   * Borders like hr and separators in lists and table
   */
  borderColor: '#393939',

  font: {
    family: '"Segoe UI", Arial, Verdana, Helvetica, sans-serif',
    colorScheme: {
      dark: 'rgba(255, 255, 255, 0.54)',
      darkInactive: 'rgba(255, 255, 255, 0.26)',
      light: 'rgba(255, 255, 255, 1)',
      lightInactive: 'rgba(255, 255, 255, 0.3)',
    },
    display1: {
      size: '112px',
      weight: 200,
      color: 'rgba(255, 255, 255, 0.54)',
    },
    display2: {
      size: '56px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)',
    },
    display3: {
      size: '45px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)',
    },
    display4: {
      size: '34px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)',
    },
    heading1: {
      size: '28px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)',
    },
    heading2: {
      size: '24px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)',
    },
    heading3: {
      size: '20px',
      weight: 500,
      color: 'rgba(255, 255, 255, 0.87)',
    },
    heading4: {
      size: '16px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)',
    },
    body: {
      size: '14px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.87)',
    },
    lead: {
      size: '14px',
      weight: 500,
      color: 'rgba(255, 255, 255, 0.87)',
    },
    caption: {
      size: '16px',
      weight: 400,
      color: 'rgba(255, 255, 255, 0.54)',
    },
  },

  /**
   * Input variables
   */
  input: {
    transition: 'height 200ms ' + easeOutFunction + ' 0ms',
    easeOutDefault: easeOutDefault,
    blockQuoteTextColor: colors.darkWhite,
    scale: {
      zero: 'scaleX(0)',
      one: 'scaleX(1)',
      default: 'scale(1) translate3d(0, 0, 0)',
      float: 'scale(0.75) translate3d(0, -26px, 0)',
    },
    colorScheme: {
      bodyTextColor: colors.white,
      disabledTextColor: colors.darkWhite,
      errorTextColor: colors.red500,
      primaryColor: primaryColor3,
    },
  },

  body: {
    //backgroundColor: '#252526',
    backgroundColor: '#333333',
  },

  /**
   * AppBar variables
   */
  appBar: {
    heightSmall: '48px',
    heightMedium: '56px',
    heightLarge: '64px',
    centerConPadding: '0 0 0 ' + gutters.small + 'px',
    title: {
      fontSize: '20px',
      fontWeight: 500,
      textAlign: 'left',
    },
    backgroundColor: primaryColor1,
    textColor: colors.darkWhite,
  },

  /**
   * List
   */
  list: {
    itemHoverColor: 'rgba(255, 255, 255, .040)',
    itemPadding: gutters.small + 'px',
    itemSelectedTextColor: 'inherit',
    itemSelectedBackgroundColor: '#3f3f46',
    // itemPrimaryColor: colors.grey50,
    // itemSecondaryColor: colors.amber200,
    subHeaderPadding: gutters.more,
  },

  table: {
    cellPadding: gutters.small + 'px',
  },

  menu: {
    backgroundColor: colors.darkBlack,
    iconColor: colors.white,
    selectedTextColor: accentColor1,
    hoverColor: 'rgba(255, 255, 255, .035)',
    disabledTextColor: colors.grey400,
    itemHeight: '48px',
    itemDataHeight: '32px',
    easeOutDefault: easeOutDefault,
  },

  /**
   * Chip variables
   */
  chip: {
    backgroundColor: primaryColor1,
    textColor: colors.white,
    fontSize: '16px',
  },

  /**
   * Toolbar variables
   */
  toolbar: {
    backgroundColor: colors.darkBlack,
  },

  /**
   * Button variables
   */
  button: {
    buttonHeight: '36px',
    buttonMinWidth: '88px',
    buttonBorderRadius: '2px',
    boxShadow: '0 1px 4px ' + colors.minBlack,
    buttonSizeNormal: 56,
    buttonSizeSmall: 40,
    buttonSizeIcon: iconSize * 2,
    textTransform: 'none',

    // Raied button
    raisedPrimaryHover: primaryColor3,
    raisedPrimaryBackgroundColor: primaryColor1,
    raisedPrimaryTextColor: colors.white,
    raisedAccentHover: accentColor3,
    raisedAccentBackgroundColor: accentColor1,
    raisedAccentTextColor: colors.white,

    // Flat Button
    flatBackgroundColor: 'transparent',
    flatTextColor: colors.white,
    flatPrimaryHover: colors.grey300,
    flatPrimaryBackgroundColor: 'transparent',
    flatPrimaryTextColor: primaryColor1,
    flatAccentHover: colors.grey300,
    flatAccentBackgroundColor: 'transparent',
    flatAccentTextColor: accentColor1,

    // Icon Button
    iconPrimaryTextColor: primaryColor1,
    iconAccenttextColor: accentColor1,

    // Dark Button
    darkHover: colors.grey50,
    darkBackgroundColor: colors.darkBlack,
    darktextColor: colors.white,

    // Light Button
    lightHover: colors.grey300,
    lightBackgroundColor: colors.white,
    lightTextColor: colors.darkBlack,

    // Disabled
    disabledTextColor: colors.grey500,
  },

  toggle: {
    toggleSize: '20px',
    checkboxSize: iconSize + 'px',
    checkedColor: primaryColor1,
    uncheckedColor: colors.white,
    thumbColorOff: colors.white,
    thumbColorOn: primaryColor1,
    trackColorOff: colors.white,
    trackColorOn: 'fade-out(' + primaryColor1 + ', 0.5)',
    transition:
      'opacity 450ms ' + easeOutFunction + ' 0ms, transform 0ms ' + easeOutFunction + ' 450ms',
    transitionCheckOn:
      'opacity 0ms ' + easeOutFunction + ' 0ms, transform 800ms ' + easeOutFunction + ' 0ms',
    easeOutBoxOn: 'all 100s ' + easeOutFunction + ' 0ms',
    easeOutIconBox: 'all 2s ' + easeOutFunction + ' 200ms',
    easeOutDefault: easeOutDefault,
  },

  tabs: {
    textColor: colors.white,
    backgroundColor: primaryColor1,
    secondaryTextColor: colors.white,
    secondaryActiveTextColor: colors.white,
    easeOutInkBar: 'left 1s ' + easeOutFunction + ' 0ms',
  },

  avatar: {
    backgroundColor: colors.grey500,
    color: colors.white,
    selectedColor: primaryColor1,
    selectedBackgroundColor: primaryColor3,
  },

  paper: {
    backgroundColorDepth1: '#252526',
    boxShadowDepth1: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth1Bottom: 'none',
    backgroundColorDepth2: '#1e1e1e',
    boxShadowDepth2: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth2Bottom: 'none',
    backgroundColorDepth3: '#131313',
    boxShadowDepth3: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth3Bottom: 'none',
    backgroundColorDepth4: '#0e0e0e',
    boxShadowDepth4: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth4Bottom: 'none',
    backgroundColorDepth5: '#000000',
    boxShadowDepth5: '0 1px 1px rgba(0, 0, 0, 0.24)',
    boxShadowDepth5Bottom: 'none',
  },
};

export default modern;
