import { material, modern, human } from './themes';
import UAParser from 'ua-parser-js';

/**
 * Auto select the theme based on the user agent
 *
 * @param {Object} uaParserArg Optional parser to use rather than newing up one
 */
export const getTheme = (uaParserArg = null) => {
  const uaParser = uaParserArg || new UAParser();

  // If we can get the OS then try and auto-detect
  if (uaParser.getOS() && uaParser.getOS().name) {
    const currentOS = uaParser.getOS().name.toLowerCase();

    switch (currentOS) {
      case 'windows phone':
      case 'windows mobile':
      case 'windows': {
        return modern;
      }
      case 'osx':
      case 'mac os':
      case 'ios': {
        return human;
      }
      case 'linux':
      case 'android': {
        return material;
      }
    }
  }

  // Default to material if nothing was found
  return material;
};
