import React from 'react';

export const isDescendant = (parent, child) => {
  var node = child.parentNode;

  while (node != null) {
    if (node == parent) return true;
    node = node.parentNode;
  }

  return false;
};

export const offset = el => {
  var rect = el.getBoundingClientRect();
  var documentOffset = scrollOffset();

  // Set simple points
  let points = {
    top: rect.top + documentOffset.top,
    left: rect.left + documentOffset.left,
    bottom: rect.bottom + documentOffset.top,
    right: rect.right + documentOffset.left,
    width: rect.width,
    height: rect.bottom - rect.top,
  };

  // Add a couple computed points from the simple
  points.middle = points.top + points.height / 2;
  points.center = points.left + points.width / 2;

  return points;
};

/**
 * Get the cumulative absolute offset of an element
 */
export const offsetAbsolute = element => {
  let top = 0,
    left = 0;
  do {
    top += element.offsetTop || 0;
    left += element.offsetLeft || 0;
    element = element.offsetParent;
  } while (element);

  return {
    top: top,
    left: left,
  };
};

export const scrollOffset = el => {
  // If we passed an element, return scroll positions of the element
  if (el) {
    return {
      top: el.scrollTop,
      left: el.scrollLeft,
    };
  }

  // Try to get the body
  var doc = document.documentElement;
  var left = (window.pageXOffset || doc.scrollLeft) - (doc.clientLeft || 0);
  var top = (window.pageYOffset || doc.scrollTop) - (doc.clientTop || 0);
  return { top: top, left: left };
};

export const addClass = (el, className) => {
  if (el.classList) el.classList.add(className);
  else el.className += ' ' + className;
};

export const removeClass = (el, className) => {
  if (el.classList) el.classList.remove(className);
  else
    el.className = el.className.replace(
      new RegExp('(^|\\b)' + className.split(' ').join('|') + '(\\b|$)', 'gi'),
      ' ',
    );
};

export const hasClass = (el, className) => {
  if (el.classList) return el.classList.contains(className);
  else return new RegExp('(^| )' + className + '( |$)', 'gi').test(el.className);
};

export const toggleClass = (el, className) => {
  if (hasClass(el, className)) removeClass(el, className);
  else addClass(el, className);
};

export const forceRedraw = el => {
  var originalDisplay = el.style.display;

  el.style.display = 'none';
  el.offsetHeight;
  el.style.display = originalDisplay;
};

export const withoutTransition = (el, callback) => {
  // We only need to do this if el.style was set
  // it is almost never set for unit tests or server-side rendering
  if (typeof el.style === 'undefined') {
    callback();
    return;
  }

  //turn off transition
  el.style.transition = 'none';

  callback();

  //force a redraw
  forceRedraw(el);

  //put the transition back
  el.style.transition = '';
};

export default {
  isDescendant,
  offset,
  offsetAbsolute,
  scrollOffset,
  addClass,
  removeClass,
  hasClass,
  toggleClass,
  forceRedraw,
  withoutTransition,
};
